@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.39 $";
+static char RcsId[] = "@(#)$Revision: 5322 $";
 #endif
 
-/* $Id: dfan.c,v 1.39 1997/10/08 17:01:15 georgev Exp $ */
+/* $Id: dfan.c 5322 2010-01-19 06:26:11Z brtnfld $ */
 
 /*-----------------------------------------------------------------------------
  * File:     dfan.c
@@ -58,7 +59,6 @@ static char RcsId[] = "@(#)$Revision: 1.39 $";
 
 #include "hdf.h"
 #include "dfan.h"
-
 PRIVATE uint16 Lastref = 0;     /* Last ref read/written */
 PRIVATE uint16 Next_label_ref = 0;  /* Next file label ref to read/write */
 PRIVATE uint16 Next_desc_ref = 0;   /* Next file desc ref to read/write */
@@ -113,16 +113,8 @@ DFANgetlablen(const char *filename, uint16 tag, uint16 ref)
 {
   int32 ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANgetlablen);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIgetannlen(filename, tag, ref, DFAN_LABEL));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANgetlablen);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -154,15 +146,7 @@ DFANgetlabel(const char *filename, uint16 tag, uint16 ref, char *label,
 {
   intn ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANgetlabel);
-#endif /* HAVE_PABLO */
-
-  ret_value = (DFANIgetann(filename, tag, ref, (uint8 *) label, maxlen, DFAN_LABEL));
-
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANgetlabel);
-#endif /* HAVE_PABLO */
+  ret_value = (DFANIgetann(filename, tag, ref, (uint8 *) label, maxlen, DFAN_LABEL, 0));
 
   return ret_value;
 }
@@ -191,16 +175,8 @@ DFANgetdesclen(const char *filename, uint16 tag, uint16 ref)
 {
   int32 ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANgetdesclen);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIgetannlen(filename, tag, ref, DFAN_DESC));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANgetdesclen);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -234,15 +210,7 @@ DFANgetdesc(const char *filename, uint16 tag, uint16 ref, char *desc,
 {
   intn ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANgetdesc);
-#endif /* HAVE_PABLO */
-
-  ret_value = (DFANIgetann(filename, tag, ref, (uint8 *) desc, maxlen, DFAN_DESC));
-
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANgetdesc);
-#endif /* HAVE_PABLO */
+  ret_value = (DFANIgetann(filename, tag, ref, (uint8 *) desc, maxlen, DFAN_DESC, 0));
 
   return ret_value;
 }
@@ -278,16 +246,8 @@ DFANgetfidlen(int32 file_id, int isfirst)
 {
   int32 ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANgetfidlen);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIgetfannlen(file_id, DFAN_LABEL, isfirst));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANgetfidlen);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -317,16 +277,8 @@ DFANgetfid(int32 file_id, char *label, int32 maxlen, intn isfirst)
 {
   int32 ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANgetfid);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIgetfann(file_id, label, maxlen, DFAN_LABEL, isfirst));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANgetfid);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -357,16 +309,8 @@ DFANgetfdslen(int32 file_id, intn isfirst)
 {
   int32 ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANgetfdslen);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIgetfannlen(file_id, DFAN_DESC, isfirst));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANgetfdslen);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -396,16 +340,8 @@ DFANgetfds(int32 file_id, char *desc, int32 maxlen, intn isfirst)
 {
   int32 ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANgetfds);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIgetfann(file_id, desc, maxlen, DFAN_DESC, isfirst));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANgetfds);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -438,17 +374,9 @@ DFANputlabel(const char *filename, uint16 tag, uint16 ref, char *label)
 {
   intn ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANputlabel);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIputann(filename, tag, ref, (uint8 *) label,
                            (int32) HDstrlen(label), DFAN_LABEL));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANputlabel);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -481,16 +409,8 @@ DFANputdesc(const char *filename, uint16 tag, uint16 ref, char *desc,
 {
   intn ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANputdesc);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIputann(filename, tag, ref, (uint8 *) desc, desclen, DFAN_DESC));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANputdesc);
-#endif /* HAVE_PABLO */
-  
   return ret_value;
 }
 
@@ -519,16 +439,8 @@ DFANaddfid(int32 file_id, char *id)
 {
   intn ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANaddfid);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIaddfann(file_id, id, (int32) HDstrlen(id), DFAN_LABEL));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANaddfid);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -556,16 +468,8 @@ DFANaddfds(int32 file_id, char *desc, int32 desclen)
 {
   intn ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANaddfds);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIaddfann(file_id, desc, desclen, DFAN_DESC));
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANaddfds);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -593,16 +497,8 @@ DFANlastref(void)
 {
   uint16 ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANlastref);
-#endif /* HAVE_PABLO */
-
   ret_value = (Lastref);
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANlastref);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -642,16 +538,8 @@ DFANlablist(const char *filename, uint16 tag, uint16 reflist[], char *labellist,
 {
   intn ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANlablist);
-#endif /* HAVE_PABLO */
-
   ret_value = (DFANIlablist(filename, tag, reflist, (uint8 *) labellist,
                             listsize, maxlen, startpos, 0));
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANlablist);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -676,16 +564,8 @@ intn DFANclear(void)
 {
   intn ret_value;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(DFAN_mask, ID_DFANclear);
-#endif /* HAVE_PABLO */
-
   ret_value = DFANIclear();
 
-#ifdef HAVE_PABLO
-  TRACE_OFF(DFAN_mask, ID_DFANclear);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }
 
@@ -727,10 +607,20 @@ DFANIclear(void)
 
   for (p=DFANdir[0]; p!=NULL; p=q) {  /* free linked list space */
     q = p->next;
+    if (p->entries != NULL)
+	    HDfree((VOIDP) p->entries);
+    p->nentries=0;
+    p->entries = NULL;
+    p->next=NULL;
     HDfree((VOIDP) p);
   }
   for (p=DFANdir[1]; p!=NULL; p=q) {
     q = p->next;
+    if (p->entries != NULL)
+	    HDfree((VOIDP) p->entries);
+    p->nentries=0;
+    p->entries = NULL;
+    p->next=NULL;
     HDfree((VOIDP) p);
   }
   DFANdir[0] = DFANdir[1] = NULL;
@@ -801,11 +691,21 @@ DFANIopen(const char *filename, intn acc_mode)
       for (p = DFANdir[0]; p != NULL; p = q)
         {   /* free linked list space */
           q = p->next;
+	    if (p->entries != NULL)
+		    HDfree((VOIDP) p->entries);
+	    p->nentries=0;
+	    p->entries = NULL;
+	    p->next=NULL;
           HDfree((VOIDP) p);
         }
       for (p = DFANdir[1]; p != NULL; p = q)
         {
           q = p->next;
+	    if (p->entries != NULL)
+		    HDfree((VOIDP) p->entries);
+	    p->nentries=0;
+	    p->entries = NULL;
+	    p->next=NULL;
           HDfree((VOIDP) p);
         }
       DFANdir[0] = DFANdir[1] = NULL;
@@ -887,12 +787,15 @@ DFANIlocate(int32 file_id, int type, uint16 tag, uint16 ref)
       if (nanns == 0)
         HGOTO_ERROR(DFE_INTERNAL, 0);
 
-      /* allocate directory space.  Note head struct includes 1 entry */
-      DFANdir[type] = (DFANdirhead *)
-        HDmalloc(((uint32) sizeof(DFANdirhead) +
-                  (size_t)(nanns - 1) * sizeof(DFANdirentry)));
+      /* allocate directory space, and space for entries. */
+      DFANdir[type] = (DFANdirhead *) HDmalloc((uint32) sizeof(DFANdirhead));
       if (DFANdir[type] == NULL)
         HGOTO_ERROR(DFE_NOSPACE, 0);
+      DFANdir[type]->entries = (DFANdirentry *)
+        HDmalloc( (size_t)nanns * sizeof(DFANdirentry));
+      if (DFANdir[type]->entries == NULL) 
+        HGOTO_ERROR(DFE_NOSPACE, 0);
+
       DFANdir[type]->next = NULL;
       DFANdir[type]->nentries = nanns;
 
@@ -997,9 +900,11 @@ DFANIaddentry(int type, uint16 annref, uint16 datatag, uint16 dataref)
     }
 
   /* need new list or new node in list */
-  /* allocate directory space.  Note head struct includes 1 entry */
-  if ((q = (DFANdirhead *) HDmalloc((uint32) sizeof(DFANdirhead) +
-               (DFAN_DEFENTRIES - 1) * sizeof(DFANdirentry))) == NULL)
+  /* allocate directory space and space for entries. */
+  if ((q = (DFANdirhead *) HDmalloc((uint32) sizeof(DFANdirhead))) == NULL)
+      HGOTO_ERROR(DFE_NOSPACE,FAIL);
+  q->entries = (DFANdirentry *) HDmalloc( DFAN_DEFENTRIES * sizeof(DFANdirentry));
+  if (q->entries == NULL)
       HGOTO_ERROR(DFE_NOSPACE,FAIL);
 
   q->next = NULL;
@@ -1106,7 +1011,7 @@ done:
        uint8 *ann;       OUT: space to return annotation in
        int32 maxlen;     IN: size of space to return annotation in
        int type;         IN: DFAN_LABEL for labels, DFAN_DESC for descriptions
-
+       int isfortran;    IN: 0 if C, 1 if Fortran
  RETURNS
        SUCCEED (0) if successful and FAIL (-1) otherwise
  DESCRIPTION
@@ -1115,12 +1020,14 @@ done:
  GLOBAL VARIABLES
        Lastref.
  COMMENTS, BUGS, ASSUMPTIONS
+       BUG 1640: Added isfortran flag to avoid termination of the string with 
+       the null character when the routine is call from FORTRAN.
  EXAMPLES
  REVISION LOG
  *------------------------------------------------------------------------*/
 intn
 DFANIgetann(const char *filename, uint16 tag, uint16 ref, uint8 *ann,
-            int32 maxlen, int type)
+            int32 maxlen, int type, int isfortran)
 {
   CONSTR(FUNC, "DFANIgetann");
   int32       file_id, aid;
@@ -1169,18 +1076,24 @@ DFANIgetann(const char *filename, uint16 tag, uint16 ref, uint8 *ann,
   annlen -= 4;    /* first four bytes were tag/ref, so they don't count */
 
   /* check length, if not enough space, truncate annotation */
-  /* labels need space for null terminator, descriptions don't */
-  if (type == DFAN_LABEL)
+  /* In C labels need space for null terminator, descriptions don't */
+  if (isfortran)
     {
-      if (annlen > maxlen - 1)
-        annlen = maxlen - 1;
+      if (annlen > maxlen )
+	annlen = maxlen;
     }
   else
-    {
-      if (annlen > maxlen)
-        annlen = maxlen;
-    }
-
+    if (type == DFAN_LABEL)
+      {
+	if (annlen > maxlen - 1)
+	  annlen = maxlen - 1;
+      }
+    else
+      {
+	if (annlen > maxlen)
+	  annlen = maxlen;
+      }
+  
   /* read annotation */
   if ((int32) FAIL == Hread(aid, (int32) 4, datadi))
     {     /* go past tag/ref */
@@ -1192,8 +1105,10 @@ DFANIgetann(const char *filename, uint16 tag, uint16 ref, uint8 *ann,
       Hendaccess(aid);
       HCLOSE_GOTO_ERROR(file_id,DFE_READERROR,FAIL);
     }
+  /* add null for C */
   if (type == DFAN_LABEL)
-    ann[annlen] = '\0';     /* terminate string properly */
+    if (!isfortran)
+      ann[annlen] = '\0'; /* terminate string properly for C */
 
   Lastref = annref;   /* remember ref last accessed */
   Hendaccess(aid);
