@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.23 $";
+static char RcsId[] = "@(#)$Revision: 4951 $";
 #endif
 
-/* $Id: dfjpeg.c,v 1.23 1997/11/13 20:19:33 acheng Exp $ */
+/* $Id: dfjpeg.c 4951 2007-09-11 19:33:41Z epourmal $ */
 
 /*-----------------------------------------------------------------------------
  * File:    dfjpeg.c
@@ -30,7 +31,6 @@ static char RcsId[] = "@(#)$Revision: 1.23 $";
 #include "hdf.h"
 #include "jpeglib.h"
 #include "jerror.h"
-
 /* Expanded data destination object for HDF output */
 
 typedef struct {
@@ -58,6 +58,9 @@ extern intn    jpeg_HDF_dest(struct jpeg_compress_struct *cinfo_ptr, int32 file_
                              uint16 ref, const void * image, int32 xdim, int32 ydim, int16 scheme);
 extern intn    jpeg_HDF_dest_term(struct jpeg_compress_struct *cinfo_ptr);
 
+void (*jpeg_message_handler)(j_common_ptr cinfo) = NULL;
+
+
 /*-----------------------------------------------------------------------------
  * Name:    hdf_init_destination
  * Purpose: Initialize the destination mgr for the JPEG image
@@ -243,14 +246,18 @@ DFCIjpeg(int32 file_id, uint16 tag, uint16 ref, int32 xdim, int32 ydim,
     intn row_stride;
     const uint8 *image_buffer=image;
 
-    if((cinfo_ptr=HDmalloc(sizeof(struct jpeg_compress_struct)))==NULL)
+    if((cinfo_ptr=HDcalloc(1,sizeof(struct jpeg_compress_struct)))==NULL)
         HRETURN_ERROR(DFE_NOSPACE,FAIL);
 
     if((jerr_ptr=HDmalloc(sizeof(struct jpeg_error_mgr)))==NULL)
         HRETURN_ERROR(DFE_NOSPACE,FAIL);
 
     /* Initialize the error-handling routines */
-    cinfo_ptr->err=jpeg_std_error(jerr_ptr);
+    cinfo_ptr->err = jpeg_std_error(jerr_ptr);
+    if (jpeg_message_handler != NULL)
+    {
+        jerr_ptr->output_message = jpeg_message_handler;
+    } 
 
     /* Initialize the JPEG compression stuff */
     jpeg_create_compress(cinfo_ptr);
@@ -279,7 +286,7 @@ DFCIjpeg(int32 file_id, uint16 tag, uint16 ref, int32 xdim, int32 ydim,
 
     /* Set up user JPEG parameters in the cinfo data structure. */
     jpeg_set_quality(cinfo_ptr, scheme_info->jpeg.quality,
-                 scheme_info->jpeg.force_baseline);
+                 (boolean)scheme_info->jpeg.force_baseline);
 
     /* OK, get things started */
     jpeg_start_compress(cinfo_ptr,TRUE);
