@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.24 $";
+static char RcsId[] = "@(#)$Revision: 6036 $";
 #endif
 
-/* $Id: dfstubs.c,v 1.24 1996/10/28 15:21:11 koziol Exp $ */
+/* $Id: dfstubs.c 6036 2014-01-20 17:28:01Z acheng $ */
 
 /*
    ** FILE
@@ -56,20 +57,10 @@ static char RcsId[] = "@(#)$Revision: 1.24 $";
 #define CKSEEKEND(x,y,z, ret)   {  if (DF_SKEND( x,(long)y,z) <0) \
                 {DFerror = DFE_SEEKERROR; return(ret); } }
 
-#ifdef VMS
-#define CKREAD(x,y,z,f, ret)    { \
-                int32 currfileposn; \
-                currfileposn = DF_TELL(f); \
-                if (DF_READ( (char*)x, (int)(y), (int)(z), (f))<0) \
-                { DFerror = DFE_READERROR; return(ret); } \
-                DF_SEEK(f, (long) (currfileposn + y*z), 0); \
-                }
-#else  /*VMS */
 #define CKREAD(x,y,z,f, ret)    { \
                 if (DF_READ( (char*)x, (int)(y), (int)(z), (f))<0) \
                 { DFerror = DFE_READERROR; return(ret); } \
                 }
-#endif /*VMS */
 
 #define CKWRITE(x,y,z,f, ret)   { if (DF_WRITE( (char*)x, (int)y, (int)z,f)<0) \
                 {DFerror = DFE_WRITEERROR; return(ret); } }
@@ -1365,10 +1356,6 @@ char       *ptr;
 int32       len;
 {
     int32       maxlen;
-#ifdef VMS
-    int32       totalread;
-    int32       readsize;
-#endif /*VMS */
     maxlen = dfile->up_dd->length -
         ((int32) DF_TELL(dfile->file) - dfile->up_dd->offset);
     if (len > maxlen)
@@ -1379,23 +1366,10 @@ int32       len;
           return (-1);
       }
 
-#ifdef VMS
-    totalread = 0;
-    while (totalread < len)
-      {
-          readsize = len - totalread;
-          if (readsize > 512)
-              readsize = 512;
-          CKREAD(&ptr[totalread], (int) readsize, 1, dfile->file, -1);
-          totalread += readsize;
-      }
-
-#else  /*VMS */
     if (len)
       {     /* NOTE: cast to (int) will limit to 64K on 16 bit m/cs */
           CKREAD(ptr, (int) len, 1, dfile->file, -1);
       }
-#endif /*VMS */
 
     return (len);
 }
