@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.2 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: dynarray.c,v 1.2 1996/10/28 15:21:15 koziol Exp $ */
+/* $Id: dynarray.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*
 FILE
@@ -85,10 +86,6 @@ dynarr_p DAcreate_array(intn start_size,      /* IN: Initial array size */
     dynarr_t   *new_arr=NULL;       /* ptr to the new dynarray */
     dynarr_p    ret_value=NULL;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(DA_mask, ID_DAcreate_array);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if(start_size<0 || incr_mult<=0)
         HGOTO_ERROR(DFE_ARGS, NULL);
@@ -120,10 +117,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(DA_mask, ID_DAcreate_array);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end DAcreate_array() */
 
@@ -148,10 +141,6 @@ intn DAdestroy_array(dynarr_p arr,  /* IN: Array to destroy */
     intn i;
     intn    ret_value=SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(DA_mask, ID_DAdestroy_array);
-#endif /* HAVE_PABLO */
-
     HEclear();
     dest_arr=(dynarr_t *)arr;
     if(dest_arr==NULL)
@@ -176,10 +165,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(DA_mask, ID_DAdestroy_array);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end DAdestroy_array() */
 
@@ -201,10 +186,6 @@ intn DAsize_array(dynarr_p arr   /* IN: Array to get size of */
     dynarr_t   *arr_ptr;            /* ptr to the dynarray destroy*/
     intn    ret_value=SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(DA_mask, ID_DAsize_array);
-#endif /* HAVE_PABLO */
-
     HEclear();
     arr_ptr=(dynarr_t *)arr;
     if(arr_ptr==NULL)
@@ -219,10 +200,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(DA_mask, ID_DAsize_array);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end DAsize_array() */
 
@@ -247,10 +224,6 @@ VOIDP DAget_elem(dynarr_p arr_ptr, /* IN: Array to access */
     dynarr_t   *arr;                /* ptr to the dynarray */
     VOIDP    ret_value=NULL;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(DA_mask, ID_DAget_elem);
-#endif /* HAVE_PABLO */
-
     HEclear();
     arr=(dynarr_t *)arr_ptr;
     if(elem<0 || arr==NULL)
@@ -268,10 +241,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(DA_mask, ID_DAget_elem);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end DAget_elem() */
 
@@ -298,10 +267,6 @@ intn DAset_elem(dynarr_p arr_ptr,  /* IN: Array to access */
     dynarr_t   *arr;                /* ptr to the dynarray */
     intn        ret_value=SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(DA_mask, ID_DAset_elem);
-#endif /* HAVE_PABLO */
-
     HEclear();
     arr=(dynarr_t *)arr_ptr;
     if(elem<0 || arr==NULL)
@@ -339,10 +304,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(DA_mask, ID_DAset_elem);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end DAset_elem() */
 
@@ -367,10 +328,6 @@ VOIDP DAdel_elem(dynarr_p arr_ptr, /* IN: Array to access */
     dynarr_t   *arr;                /* ptr to the dynarray */
     VOIDP    ret_value=NULL;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(DA_mask, ID_DAdel_elem);
-#endif /* HAVE_PABLO */
-
     HEclear();
     arr=(dynarr_t *)arr_ptr;
     if(elem<0 || arr==NULL)
@@ -391,10 +348,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(DA_mask, ID_DAdel_elem);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end DAdel_elem() */
 
