@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.37 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: hbitio.c,v 1.37 1996/10/28 22:48:26 koziol Exp $ */
+/* $Id: hbitio.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*
 FILE
@@ -767,10 +768,6 @@ PRIVATE intn HIbitstart(void)
     CONSTR(FUNC, "HIbitstart");    /* for HERROR */
     intn        ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-  TRACE_ON(H_mask, ID_HIbitstart);
-#endif /* HAVE_PABLO */
-
     /* Don't call this routine again... */
     library_terminate = TRUE;
 
@@ -785,10 +782,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-  TRACE_OFF(H_mask, ID_HIbitstart);
-#endif /* HAVE_PABLO */
-
     return(ret_value);
 } /* end HIbitstart() */
 
@@ -830,7 +823,7 @@ HIbitflush(bitrec_t * bitfile_rec, intn flushbit, intn writeout)
 
     if (bitfile_rec->count < (intn)BITNUM)
       {     /* check if there are any */
-          if (bitfile_rec->byte_offset >= bitfile_rec->max_offset)
+          if (bitfile_rec->byte_offset > bitfile_rec->max_offset)
             {
                 if (flushbit != (-1))   /* only flush bits if asked and there are bits to flush */
                     if (Hbitwrite(bitfile_rec->bit_id, bitfile_rec->count, (uint32) (flushbit ? 0xFF : 0)) == FAIL)
@@ -845,7 +838,14 @@ HIbitflush(bitrec_t * bitfile_rec, intn flushbit, intn writeout)
                 *(bitfile_rec->bytep) |= bitfile_rec->bits;
 
                 bitfile_rec->bytep++;
+                bitfile_rec->byte_offset++;
+                
+                /* Update the offset in the buffer */
+                if (bitfile_rec->byte_offset > bitfile_rec->max_offset)
+                    bitfile_rec->max_offset = bitfile_rec->byte_offset;
+
                 bitfile_rec->count = BITNUM;    /* reset count */
+                bitfile_rec->bits=0;            /* reset bits */
             }   /* end else */
       }     /* end if */
     if (writeout == TRUE)
