@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.79 $";
+static char RcsId[] = "@(#)$Revision: 6043 $";
 #endif
 
-/* $Id: hextelt.c,v 1.79 1998/02/02 21:38:48 smitchel Exp $ */
+/* $Id: hextelt.c 6043 2014-01-21 21:09:03Z acheng $ */
 
 /*LINTLIBRARY */
 /* ------------------------------ hextelt.c -------------------------------
@@ -86,26 +87,15 @@ EXPORTED ROUTINES
 /* Directory seperator definitions relating to a path. 
  * Note this does not provide a universal way to recognize
  * different path name conventions and translate between them */
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) 
-#define DIR_SEPC  58  /* Integer value of ':' */
-#define DIR_SEPS  ":"
-#else /* not Macintosh */
 #if defined WIN386 | defined DOS386
 /* DOS-Windows seperator */
 #define DIR_SEPC  92  /* Integer value of '\' */
 #define DIR_SEPS  "\\"
 #else 
-#if defined VMS
-/* VMS -made it the same as POSIX for now eventhought it should be '.' */
-#define DIR_SEPC  47  /* Integer value of '/' */
-#define DIR_SEPS  "/"
-#else
 /* Unix - POSIX */
 #define DIR_SEPC  47  /* Integer value of '/' */
 #define DIR_SEPS  "/"
-#endif /* !VMS */
 #endif /* !WIN386 & !DOS386 */
-#endif /* !Macintosh */
 
 /* directory path seperator from other directory paths */
 #define DIR_PATH_SEPC 124
@@ -187,7 +177,7 @@ DESCRIPTION
    element applies to the content of the external file.
 
    The AID which refers to this new external element, is returned upon
-   successiful execution.  FAIL is returned if any error is encountered.
+   successful execution.  FAIL is returned if any error is encountered.
 FORTRAN
    None
 
@@ -209,9 +199,6 @@ HXcreate(int32 file_id, uint16 tag, uint16 ref, const char *extern_file_name, in
     void *       buf = NULL;      /* temporary buffer */
     int32       ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(H_mask, ID_HXcreate);
-#endif /* HAVE_PABLO */
     /* clear error stack and validate args */
     HEclear();
     file_rec = HAatom_object(file_id);
@@ -270,10 +257,10 @@ HXcreate(int32 file_id, uint16 tag, uint16 ref, const char *extern_file_name, in
         HGOTO_ERROR(DFE_BADOPEN, FAIL);
 
     /* create the external file */
-    file_external = HI_OPEN(fname, DFACC_WRITE);
+    file_external = (hdf_file_t)HI_OPEN(fname, DFACC_WRITE);
     if (OPENERR(file_external))
     {
-        file_external = HI_CREATE(fname);
+        file_external = (hdf_file_t)HI_CREATE(fname);
         if (OPENERR(file_external))
             HGOTO_ERROR(DFE_BADOPEN, FAIL);
     }
@@ -323,7 +310,7 @@ HXcreate(int32 file_id, uint16 tag, uint16 ref, const char *extern_file_name, in
         if (HTPdelete(data_id) == FAIL)
             HGOTO_ERROR(DFE_CANTDELDD, FAIL);
 
-    /* write the special info structure to fill */
+    /* write the special info structure to file */
     if((dd_aid=Hstartaccess(file_id,special_tag,ref,DFACC_ALL))==FAIL)
         HGOTO_ERROR(DFE_CANTACCESS, FAIL);
     if (Hwrite(dd_aid, 14+info->length_file_name, local_ptbuf) == FAIL)
@@ -361,9 +348,6 @@ done:
   if (buf != NULL)
       HDfree(buf);
 
-#ifdef HAVE_PABLO
-    TRACE_OFF(H_mask, ID_HXcreate);
-#endif /* HAVE_PABLO */
   return ret_value; 
 } /* HXcreate */
 
@@ -406,10 +390,10 @@ HXPsetaccesstype(accrec_t * access_rec)
     switch (access_rec->access_type)
       {
           case DFACC_SERIAL:
-              file_external = HI_OPEN(fname, DFACC_WRITE);
+              file_external = (hdf_file_t)HI_OPEN(fname, DFACC_WRITE);
               if (OPENERR(file_external))
                 {
-                    file_external = HI_CREATE(fname);
+                    file_external = (hdf_file_t)HI_CREATE(fname);
                     if (OPENERR(file_external))
                         HGOTO_ERROR(DFE_BADOPEN, FAIL);
                 }
@@ -674,7 +658,7 @@ HXPread(accrec_t * access_rec, int32 length, void * data)
         if ((fname = HXIbuildfilename(info->extern_file_name, DFACC_OLD))==NULL)
             HGOTO_ERROR(DFE_BADOPEN, FAIL);
 
-        info->file_external = HI_OPEN(fname, access_rec->access);
+        info->file_external = (hdf_file_t)HI_OPEN(fname, access_rec->access);
         HDfree(fname);
         if (OPENERR(info->file_external))
           {
@@ -734,11 +718,13 @@ HXPwrite(accrec_t * access_rec, int32 length, const void * data)
     CONSTR(FUNC, "HXPwrite");   /* for HERROR */
     extinfo_t  *info =          /* information on the special element */
                     (extinfo_t *) (access_rec->special_info);
-    uint8      *p =local_ptbuf;/* temp buffer ptr */
-    filerec_t  *file_rec =     /* file record */
-                          HAatom_object(access_rec->file_id);
+    uint8      *p =local_ptbuf; /* temp buffer ptr */
+    filerec_t  *file_rec;       /* file record */
     int32      ret_value = SUCCEED;
 
+    /* convert file id to file record */
+    file_rec = HAatom_object(access_rec->file_id);
+
     /* validate length */
     if (length < 0)
         HGOTO_ERROR(DFE_RANGE, FAIL);
@@ -752,7 +738,7 @@ HXPwrite(accrec_t * access_rec, int32 length, const void * data)
         if ((fname = HXIbuildfilename(info->extern_file_name, DFACC_OLD))==NULL)
             HGOTO_ERROR(DFE_BADOPEN, FAIL);
 
-        info->file_external = HI_OPEN(fname, access_rec->access);
+        info->file_external = (hdf_file_t)HI_OPEN(fname, access_rec->access);
         HDfree(fname);
         if (OPENERR(info->file_external))
           {
@@ -771,7 +757,7 @@ HXPwrite(accrec_t * access_rec, int32 length, const void * data)
             {
             /* this external file might not be opened with write permission,
                reopen the file and try again */
-                hdf_file_t  f = HI_OPEN(info->extern_file_name, DFACC_WRITE);
+                hdf_file_t  f = (hdf_file_t)HI_OPEN(info->extern_file_name, DFACC_WRITE);
                 
                 if (OPENERR(f) ||
                     HI_SEEK(f, access_rec->posn + info->extern_offset) == FAIL ||
@@ -902,10 +888,12 @@ intn
 HXPendaccess(accrec_t * access_rec)
 {
     CONSTR(FUNC, "HXPendaccess");   /* for HERROR */
-    filerec_t  *file_rec =      /* file record */
-        HAatom_object(access_rec->file_id);
+    filerec_t  *file_rec;           /* file record */
     intn     ret_value = SUCCEED;
 
+    /* convert file id to file record */
+    file_rec = HAatom_object(access_rec->file_id);
+
     /* close the file pointed to by this access rec */
     HXPcloseAID(access_rec);
 
@@ -1022,6 +1010,8 @@ HXPinfo(accrec_t * access_rec, sp_info_block_t * info_block)
     info_block->key = SPECIAL_EXT;
 
     info_block->offset = info->extern_offset;
+    info_block->length = info->length;
+    info_block->length_file_name = info->length_file_name;
     info_block->path = info->extern_file_name;
 
 done:
@@ -1156,9 +1146,6 @@ HXsetcreatedir(const char *dir)
   char	*pt;
   intn       ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(H_mask, ID_HXsetcreatedir);
-#endif /* HAVE_PABLO */
 
   if (dir)
     {
@@ -1180,9 +1167,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(H_mask, ID_HXsetcreatedir);
-#endif /* HAVE_PABLO */
   return ret_value; 
 }	/* HXsetcreatedir */
 
@@ -1213,9 +1197,6 @@ HXsetdir(const char *dir)
   char	*pt;
   intn   ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(H_mask, ID_HXsetdir);
-#endif /* HAVE_PABLO */
   if (dir)
     {
       if (!(pt = HDstrdup(dir)))
@@ -1236,9 +1217,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(H_mask, ID_HXsetdir);
-#endif /* HAVE_PABLO */
   return ret_value; 
 }	/* HXsetdir */
 
@@ -1261,6 +1239,7 @@ DESCRIPTION
 /* for end-of-line two extra times, or even use memcpy since the string lengths */
 /* are calculated already.  For now, it works. */
 #define HDstrcpy3(s1, s2, s3, s4)	(HDstrcat(HDstrcat(HDstrcpy(s1, s2),s3),s4))
+#define HDstrcpy4(s1, s2, s3, s4, s5)	(HDstrcat(HDstrcat(HDstrcat(HDstrcpy(s1, s2),s3),s4),s5))
 
 PRIVATE
 char *
@@ -1273,9 +1252,7 @@ HXIbuildfilename(const char *ext_fname, const intn acc_mode)
 
     char	*finalpath = NULL;	/* Final pathname to return */
     const char	*fname = NULL;
-#if !(defined (MAC) || defined (macintosh) || defined (SYMANTEC_C))
     struct	stat filestat;	/* for checking pathname existence */
-#endif
     char        *ret_value = NULL; /* FAIL */
 
     /* initialize HDFEXTDIR and HDFCREATEDIR if invoked the first time */
@@ -1345,7 +1322,6 @@ HXIbuildfilename(const char *ext_fname, const intn acc_mode)
             /* strip the pathname component */
             fname = HDstrrchr(fname, DIR_SEPC) + 1;
             fname_len = (int)HDstrlen(fname);
-
             /* continue to Relative Pathname */
         }
 
