@@ -1,16 +1,17 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: hfile.h,v 1.105 1998/02/19 16:27:16 bljones Exp $ */
+/* $Id: hfile.h 6079 2014-02-08 00:29:03Z bmribler $ */
 
 /*+ hfile.h
    *** Header for hfile.c, routines for low level data element I/O
@@ -19,6 +20,8 @@
 #ifndef HFILE_H
 #define HFILE_H
 
+#include "H4api_adpt.h"
+
 #include "tbbt.h"
 #include "bitvect.h"
 #include "atom.h"
@@ -47,9 +50,11 @@
 /* Library version numbers */
 
 #define LIBVER_MAJOR    4
-#define LIBVER_MINOR    1 
-#define LIBVER_RELEASE  2 
-#define LIBVER_STRING   "NCSA HDF Version 4.1 Release 2, March 1998"
+#define LIBVER_MINOR    2 
+#define LIBVER_RELEASE  10 
+#define LIBVER_SUBRELEASE ""   /* For pre-releases like snap0       */
+                                /* Empty string for real releases.           */
+#define LIBVER_STRING   "HDF Version 4.2 Release 10, February 7, 2014"
 #define LIBVSTR_LEN    80   /* length of version string  */
 #define LIBVER_LEN  92      /* 4+4+4+80 = 92 */
 /* end of version tags */
@@ -66,13 +71,6 @@
 /* using C buffered file I/O routines to access files */
 #include <stdio.h>
 typedef FILE *hdf_file_t;
-#ifdef VMS
-/* For VMS, use "mbc=64" to improve performance     */
-#   define HI_OPEN(p, a)       (((a) & DFACC_WRITE) ? \
-                                fopen((p), "r+", "mbc=64") : \
-                                fopen((p), "r", "mbc=64"))
-#   define HI_CREATE(p)        (fopen((p), "w+", "mbc=64"))
-#else  /*  !VMS  */
 #if defined SUN && defined (__GNUC__)
 #   define HI_OPEN(p, a)       (((a) & DFACC_WRITE) ? \
                                 fopen((p), "r+") : fopen((p), "r"))
@@ -82,12 +80,11 @@ typedef FILE *hdf_file_t;
                                 fopen((p), "rb+") : fopen((p), "rb"))
 #   define HI_CREATE(p)        (fopen((p), "wb+"))
 #endif /* !SUN w/ GNU CC */
-#endif /* VMS */
 #   define HI_READ(f, b, n)    (((size_t)(n) == (size_t)fread((b), 1, (size_t)(n), (f))) ? \
                                 SUCCEED : FAIL)
 #   define HI_WRITE(f, b, n)   (((size_t)(n) == (size_t)fwrite((b), 1, (size_t)(n), (f))) ? \
                                 SUCCEED : FAIL)
-#   define HI_CLOSE(f)   (fclose(f))
+#   define HI_CLOSE(f)   (((f = ((fclose(f)==0) ? NULL : f))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(f)   (fflush(f)==0 ? SUCCEED : FAIL)
 #   define HI_SEEK(f,o)  (fseek((f), (long)(o), SEEK_SET)==0 ? SUCCEED : FAIL)
 #   define HI_SEEK_CUR(f,o)  (fseek((f), (long)(o), SEEK_CUR)==0 ? SUCCEED : FAIL)
@@ -102,7 +99,7 @@ typedef int hdf_file_t;
 #   define HI_OPEN(p, a)       (((a) & DFACC_WRITE) ? \
                                     open((p), O_RDWR) : open((p), O_RDONLY))
 #   define HI_CREATE(p)         (open((p), O_RDWR | O_CREAT | O_TRUNC, 0666))
-#   define HI_CLOSE(f)          (close(f))
+#   define HI_CLOSE(f)          (((f = ((close(f)==0) ? NULL : f))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(f)          (SUCCEED)
 #   define HI_READ(f, b, n)     (((n)==read((f), (char *)(b), (n))) ? SUCCEED : FAIL)
 #   define HI_WRITE(f, b, n)    (((n)==write((f), (char *)(b), (n))) ? SUCCEED : FAIL)
@@ -117,7 +114,7 @@ typedef int hdf_file_t;
 typedef short hdf_file_t;
 #   define HI_OPEN(x,y)         mopen(x,y)
 #   define HI_CREATE(name)      mopen(name, DFACC_CREATE)
-#   define HI_CLOSE(x)          mclose(x)
+#   define HI_CLOSE(x)          (((x = ((mclose(x)==0) ? NULL : x))==NULL) ? SUCCEED:FAIL)
 #   define HI_FLUSH(a)          (SUCCEED)
 #   define HI_READ(a,b,c)       mread(a, (char *) b, (int32) c)
 #   define HI_WRITE(a,b,c)      mwrite(a, (char *) b, (int32) c)
@@ -128,81 +125,6 @@ typedef short hdf_file_t;
 #   define OPENERR(f)           (f < 0)
 #endif /* FILELIB == MACIO */
 
-#ifdef NOT_USED     /* Deprecated routines, not supported any more */
-#if (FILELIB == PCIO)
-/* using special PC functions to enable reading/writing large chunks */
-typedef FILE *hdf_file_t;
-#   define HI_OPEN(p, a)       (((a) & DFACC_WRITE) ? \
-                                fopen((p), "rb+") : fopen((p), "rb"))
-#   define HI_CREATE(p)        (fopen((p), "wb+"))
-/* Alias the HI_READ and HI_WRITE macros to functions which can handle */
-/*  32-bits of data to read/write */
-#   define HI_READ(f, b, n)    (((int32)(n) == HDfreadbig((b), (n), (f))) ? \
-                                SUCCEED : FAIL)
-#   define HI_WRITE(f, b, n)   (((int32)(n) == HDfwritebig((b), (n), (f))) ? \
-                                SUCCEED : FAIL)
-#   define HI_CLOSE(f)          (fclose(f))
-#   define HI_FLUSH(f)          (fflush(f)==0 ? SUCCEED : FAIL)
-#   define HI_SEEK(f,o)  (fseek((f), (long)(o), SEEK_SET)==0 ? SUCCEED : FAIL)
-#   define HI_SEEKEND(f) (fseek((f), (long)0, SEEK_END)==0 ? SUCCEED : FAIL)
-#   define HI_TELL(f)           (ftell(f))
-#   define OPENERR(f)           ((f) == (FILE *)NULL)
-#endif /* FILELIB == PCIO */
-
-#if (FILELIB == WINIO)
-/* using special MS Windows functions to enable reading/writing large chunks */
-typedef HFILE hdf_file_t;
-#   define HI_OPEN(p, a)       (((a) & DFACC_WRITE) ? \
-                                _lopen((p), READ_WRITE) : _lopen((p), READ))
-#   define HI_CREATE(p)        (_lcreat((p), 0))
-/* Alias the HI_READ and HI_WRITE macros to functions which can handle */
-/*  32-bits of data to read/write */
-#   define HI_READ(f, b, n)    (((int32)(n) == HDfreadbig((b), (n), (f))) ? \
-                                SUCCEED : FAIL)
-#   define HI_WRITE(f, b, n)   (((int32)(n) == HDfwritebig((b), (n), (f))) ? \
-                                SUCCEED : FAIL)
-#   define HI_CLOSE(f)          (_lclose(f))
-#   define HI_FLUSH(f)          (0)
-#   define HI_SEEK(f, o)        (_llseek((f), (long)(o), SEEK_SET))
-#   define HI_SEEKEND(f)        (_llseek((f), (long)0, SEEK_END))
-#   define HI_TELL(f)           (_llseek((f),0l,SEEK_CUR))
-#   define OPENERR(f)           ((f) == (HFILE)HFILE_ERROR)
-#endif /* FILELIB == WINIO */
-
-#if (FILELIB == WINNTIO)
-/* using special Windows NT functions to enable reading/writing large chunks */
-typedef HFILE hdf_file_t;
-#   define HI_OPEN(p, a)       (((a) & DFACC_WRITE) ? \
-                        _lopen((p), OF_READWRITE) : _lopen((p), OF_READ))
-#   define HI_CREATE(p)        (_lcreat((p), 0))
-#   define HI_READ(f, b, n)    (((int32)(n) == _hread((f), (b), (n))) ? \
-                                SUCCEED : FAIL)
-#   define HI_WRITE(f, b, n)   (((int32)(n) == _hwrite((f), (b), (n))) ? \
-                                SUCCEED : FAIL)
-#   define HI_CLOSE(f) (_lclose(f)==0 ? SUCCEED : FAIL)
-#   define HI_FLUSH(f) (0)
-#   define HI_SEEK(f, o)       (_llseek((f), (long)(o), 0))
-#   define HI_SEEKEND(f) (_llseek((f), (long)0, 2))
-#   define HI_TELL(f)  (_llseek((f),0l,1))
-#   define OPENERR(f)  ((f) == (HFILE)HFILE_ERROR)
-#endif /* FILELIB == WINNTIO */
-#endif /* NOT_USED */
-
-#if (FILELIB == PAGEBUFIO)
-#include "fmpio.h"
-/* using page buffered file I/O routines to access files */
-typedef MPFILE *hdf_file_t;
-#   define HI_OPEN(p, a)        (MPopen((p), (a)))
-#   define HI_CREATE(p)         (MPopen((p), DFACC_CREATE))
-#   define HI_CLOSE(f)          (MPclose(f))
-#   define HI_FLUSH(f)          (MPflush(f))
-#   define HI_READ(f, b, n)     (MPread((f), (char *)(b), (n)))
-#   define HI_WRITE(f, b, n)    (MPwrite((f), (char *)(b), (n)))
-#   define HI_SEEK(f, o)        (MPseek((f), (off_t)(o), SEEK_SET))
-#   define HI_SEEKEND(f)        (MPseek((f), (off_t)0, SEEK_END))
-#   define HI_TELL(f)           (MPseek((f), (off_t)0, SEEK_CUR))
-#   define OPENERR(f)           ((f) == (MPFILE *)NULL)
-#endif /* FILELIB == PAGEBUFIO */
 
 /* ----------------------- Internal Data Structures ----------------------- */
 /* The internal structure used to keep track of the files opened: an
@@ -337,10 +259,10 @@ typedef struct tag_info_str
 /* For determining what the last file operation was */
 typedef enum
   {
-      OP_UNKNOWN = 0,   /* Don't know what the last operation was (after fopen frex) */
-      OP_SEEK,          /* Last operation was a seek */
-      OP_WRITE,         /* Last operation was a write */
-      OP_READ           /* Last operation was a read */
+      H4_OP_UNKNOWN = 0,   /* Don't know what the last operation was (after fopen frex) */
+      H4_OP_SEEK,          /* Last operation was a seek */
+      H4_OP_WRITE,         /* Last operation was a write */
+      H4_OP_READ           /* Last operation was a read */
   }
 fileop_t;
 
@@ -399,7 +321,8 @@ typedef struct accrec_t
       intn        appendable;   /* whether appends to the data are allowed */
       intn        special;      /* special element ? */
       intn        new_elem;     /* is a new element (i.e. no length set yet) */
-      
+      int32       block_size;   /* size of the blocks for linked-block element*/
+      int32       num_blocks;   /* number blocks in the linked-block element */
       uint32      access;       /* access codes */
       uintn       access_type;  /* I/O access type: serial/parallel/... */
       int32       file_id;      /* id of attached file */
@@ -420,12 +343,16 @@ static accrec_t *accrec_free_list=NULL;
    interfaces when they need to know information about a given
    special element.  This is all information that would not be returned
    via Hinquire().  This should probably be a union of structures. */
+/* Added length of external element.  Note: this length is not returned
+   via Hinquire(). -BMR 2011/12/12 */
 typedef struct sp_info_block_t
   {
       int16       key;          /* type of special element this is */
 
       /* external elements */
       int32       offset;       /* offset in the file */
+      int32       length;       /* length of external data in the file */
+      int32       length_file_name;  /* length of external file name */
       char       *path;         /* file name - should not be freed by user */
 
       /* linked blocks */
@@ -445,6 +372,9 @@ typedef struct sp_info_block_t
       int32       chunk_size;   /* logical size of chunks */
       int32       ndims;        /* number of dimensions */
       int32       *cdims;       /* array of chunk lengths for each dimension */
+
+      /* Buffered elements */
+      int32       buf_aid;      /* AID of element buffered */
   }
 sp_info_block_t;
 
@@ -532,204 +462,236 @@ extern      "C"
 {
 #endif                          /* c_plusplus || __cplusplus */
 
-    extern accrec_t *HIget_access_rec
+    HDFLIBAPI accrec_t *HIget_access_rec
                 (void);
 
-    extern void HIrelease_accrec_node(accrec_t *acc);
+    HDFLIBAPI void HIrelease_accrec_node(accrec_t *acc);
 
-    extern void * HIgetspinfo
+    HDFLIBAPI void * HIgetspinfo
                 (accrec_t * access_rec);
 
-    extern intn HPcompare_filerec_path
+    HDFLIBAPI intn HPcompare_filerec_path
                 (const void * obj, const void * key);
 
-    extern intn HPcompare_accrec_tagref
+    HDFLIBAPI intn HPcompare_accrec_tagref
                 (const void * rec1, const void * rec2);
 
-    extern int32 HPgetdiskblock
+    HDFLIBAPI int32 HPgetdiskblock
                 (filerec_t * file_rec, int32 block_size, intn moveto);
 
-    extern intn HPfreediskblock
+    HDFLIBAPI intn HPfreediskblock
                 (filerec_t * file_rec, int32 block_offset, int32 block_size);
 
-    extern int32 HDget_special_info
+    HDFLIBAPI intn HPisfile_in_use
+                (const char *path);
+
+    HDFLIBAPI int32 HDcheck_empty
+                (int32 file_id, uint16 tag, uint16 ref, intn *emptySDS);
+
+    HDFLIBAPI int32 HDget_special_info
                 (int32 access_id, sp_info_block_t * info_block);
 
-    extern intn HP_read
+    HDFLIBAPI int32 HDset_special_info
+                (int32 access_id, sp_info_block_t * info_block);
+
+    HDFLIBAPI intn HP_read
                 (filerec_t *file_rec,void * buf,int32 bytes);
 
-    extern intn HPseek
+    HDFLIBAPI intn HPseek
                 (filerec_t *file_rec,int32 offset);
 
-    extern intn HP_write
+    HDFLIBAPI intn HP_write
                 (filerec_t *file_rec,const void * buf,int32 bytes);
 
-    extern intn tagcompare
+    HDFLIBAPI int32 HPread_drec
+                (int32 file_id, atom_t data_id, uint8** drec_buf);
+
+    HDFLIBAPI intn tagcompare
                 (void * k1, void * k2, intn cmparg);
 
-    extern VOID tagdestroynode
+    HDFLIBAPI VOID tagdestroynode
                 (void * n);
 
 /*
    ** from hblocks.c
  */
-    extern int32 HLPstread
+    HDFLIBAPI int32 HLPstread
                 (accrec_t * access_rec);
 
-    extern int32 HLPstwrite
+    HDFLIBAPI int32 HLPstwrite
                 (accrec_t * access_rec);
 
-    extern int32 HLPseek
+    HDFLIBAPI int32 HLPseek
                 (accrec_t * access_rec, int32 offset, int origin);
 
-    extern int32 HLPread
+    HDFLIBAPI int32 HLPread
                 (accrec_t * access_rec, int32 length, void * data);
 
-    extern int32 HLPwrite
+    HDFLIBAPI int32 HLPwrite
                 (accrec_t * access_rec, int32 length, const void * data);
 
-    extern int32 HLPinquire
+    HDFLIBAPI int32 HLPinquire
                 (accrec_t * access_rec, int32 *pfile_id, uint16 *ptag, uint16 *pref,
                int32 *plength, int32 *poffset, int32 *pposn, int16 *paccess,
                  int16 *pspecial);
 
-    extern intn HLPendaccess
+    HDFLIBAPI intn HLPendaccess
                 (accrec_t * access_rec);
 
-    extern int32 HLPcloseAID
+    HDFLIBAPI int32 HLPcloseAID
                 (accrec_t * access_rec);
 
-    extern int32 HLPinfo
+    HDFLIBAPI int32 HLPinfo
                 (accrec_t * access_rec, sp_info_block_t * info_block);
 
 /*
    ** from hextelt.c
  */
-    extern int32 HXPstread
+    HDFLIBAPI int32 HXPstread
                 (accrec_t * rec);
 
-    extern int32 HXPstwrite
+    HDFLIBAPI int32 HXPstwrite
                 (accrec_t * rec);
 
-    extern int32 HXPseek
+    HDFLIBAPI int32 HXPseek
                 (accrec_t * access_rec, int32 offset, int origin);
 
-    extern int32 HXPread
+    HDFLIBAPI int32 HXPread
                 (accrec_t * access_rec, int32 length, void * data);
 
-    extern int32 HXPwrite
+    HDFLIBAPI int32 HXPwrite
                 (accrec_t * access_rec, int32 length, const void * data);
 
-    extern int32 HXPinquire
+    HDFLIBAPI int32 HXPinquire
                 (accrec_t * access_rec, int32 *pfile_id, uint16 *ptag, uint16 *pref,
                int32 *plength, int32 *poffset, int32 *pposn, int16 *paccess,
                  int16 *pspecial);
 
-    extern intn HXPendaccess
+    HDFLIBAPI intn HXPendaccess
                 (accrec_t * access_rec);
 
-    extern int32 HXPcloseAID
+    HDFLIBAPI int32 HXPcloseAID
                 (accrec_t * access_rec);
 
-    extern int32 HXPinfo
+    HDFLIBAPI int32 HXPinfo
                 (accrec_t * access_rec, sp_info_block_t * info_block);
 
-    extern int32 HXPreset
+    HDFLIBAPI int32 HXPreset
                 (accrec_t * access_rec, sp_info_block_t * info_block);
 
-    extern intn HXPsetaccesstype
+    HDFLIBAPI intn HXPsetaccesstype
                 (accrec_t * access_rec);
 
-    extern intn HXPshutdown
+    HDFLIBAPI intn HXPshutdown
                 (void);
 
 /*
    ** from hcomp.c
  */
 
-    extern int32 HCPstread
+    HDFLIBAPI int32 HCPstread
                 (accrec_t * rec);
 
-    extern int32 HCPstwrite
+    HDFLIBAPI int32 HCPstwrite
                 (accrec_t * rec);
 
-    extern int32 HCPseek
+    HDFLIBAPI int32 HCPseek
                 (accrec_t * access_rec, int32 offset, int origin);
 
-    extern int32 HCPinquire
+    HDFLIBAPI int32 HCPinquire
                 (accrec_t * access_rec, int32 *pfile_id, uint16 *ptag, uint16 *pref,
                int32 *plength, int32 *poffset, int32 *pposn, int16 *paccess,
                  int16 *pspecial);
 
-    extern int32 HCPread
+    HDFLIBAPI int32 HCPread
                 (accrec_t * access_rec, int32 length, void * data);
 
-    extern int32 HCPwrite
+    HDFLIBAPI int32 HCPwrite
                 (accrec_t * access_rec, int32 length, const void * data);
 
-    extern intn HCPendaccess
+    HDFLIBAPI intn HCPendaccess
                 (accrec_t * access_rec);
 
-    extern int32 HCPcloseAID
+    HDFLIBAPI int32 HCPcloseAID
                 (accrec_t * access_rec);
 
-    extern int32 HCPinfo
+    HDFLIBAPI int32 HCPinfo
                 (accrec_t * access_rec, sp_info_block_t * info_block);
 
-/*
-   ** from hvblocks.c
- */
-
-    extern int32 HVPstread
-                (accrec_t * rec);
-
-    extern int32 HVPstwrite
-                (accrec_t * rec);
-
-    extern int32 HVPseek
-                (accrec_t * access_rec, int32 offset, int origin);
-
-    extern int32 HVPinquire
-                (accrec_t * access_rec, int32 *pfile_id, uint16 *ptag, uint16 *pref,
-               int32 *plength, int32 *poffset, int32 *pposn, int16 *paccess,
-                 int16 *pspecial);
-
-    extern int32 HVPread
-                (accrec_t * access_rec, int32 length, void * data);
-
-    extern int32 HVPwrite
-                (accrec_t * access_rec, int32 length, const void * data);
-
-    extern intn HVPendaccess
-                (accrec_t * access_rec);
-
-    extern int32 HVPinfo
-                (accrec_t * access_rec, sp_info_block_t * info_block);
+    HDFLIBAPI int32 get_comp_len
+	        (accrec_t* access_rec);
 
 /*
    ** from hchunks.c - should be the same as found in 'hchunks.h'
  */
 #include "hchunks.h"
 
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C)
-    extern hdf_file_t mopen
-                (char *filename, intn access);
 
-    extern int32 mclose
-                (hdf_file_t rn);
+/*
+   ** from hbuffer.c
+ */
 
-    extern int32 mlseek
-                (hdf_file_t rn, int32 n, intn m);
+    HDFLIBAPI int32 HBPstread
+                (accrec_t * rec);
 
-    extern int32 mread
-                (hdf_file_t rn, char *buf, int32 n);
+    HDFLIBAPI int32 HBPstwrite
+                (accrec_t * rec);
 
-    extern int32 mwrite
-                (hdf_file_t rn, char *buf, int32 n);
-    extern intn mstat
-                (char *path);
+    HDFLIBAPI int32 HBPseek
+                (accrec_t * access_rec, int32 offset, int origin);
 
-#endif  /* macintosh */
+    HDFLIBAPI int32 HBPinquire
+                (accrec_t * access_rec, int32 *pfile_id, uint16 *ptag, uint16 *pref,
+               int32 *plength, int32 *poffset, int32 *pposn, int16 *paccess,
+                 int16 *pspecial);
+
+    HDFLIBAPI int32 HBPread
+                (accrec_t * access_rec, int32 length, void * data);
+
+    HDFLIBAPI int32 HBPwrite
+                (accrec_t * access_rec, int32 length, const void * data);
+
+    HDFLIBAPI intn HBPendaccess
+                (accrec_t * access_rec);
+
+    HDFLIBAPI int32 HBPcloseAID
+                (accrec_t * access_rec);
+
+    HDFLIBAPI int32 HBPinfo
+                (accrec_t * access_rec, sp_info_block_t * info_block);
+
+/*
+   ** from hcompri.c
+ */
+
+    HDFLIBAPI int32 HRPstread
+                (accrec_t * rec);
+
+    HDFLIBAPI int32 HRPstwrite
+                (accrec_t * rec);
+
+    HDFLIBAPI int32 HRPseek
+                (accrec_t * access_rec, int32 offset, int origin);
+
+    HDFLIBAPI int32 HRPinquire
+                (accrec_t * access_rec, int32 *pfile_id, uint16 *ptag, uint16 *pref,
+               int32 *plength, int32 *poffset, int32 *pposn, int16 *paccess,
+                 int16 *pspecial);
+
+    HDFLIBAPI int32 HRPread
+                (accrec_t * access_rec, int32 length, void * data);
+
+    HDFLIBAPI int32 HRPwrite
+                (accrec_t * access_rec, int32 length, const void * data);
+
+    HDFLIBAPI intn HRPendaccess
+                (accrec_t * access_rec);
+
+    HDFLIBAPI int32 HRPcloseAID
+                (accrec_t * access_rec);
+
+    HDFLIBAPI int32 HRPinfo
+                (accrec_t * access_rec, sp_info_block_t * info_block);
 
 /*
    ** from hfiledd.c
