@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.22 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: hfilef.c,v 1.22 1998/02/12 23:49:52 epourmal Exp $ */
+/* $Id: hfilef.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*-----------------------------------------------------------------------------
  * File:    hfilef.c
@@ -26,27 +27,7 @@ static char RcsId[] = "@(#)$Revision: 1.22 $";
  *---------------------------------------------------------------------------*/
 
 #include "hdf.h"
-
-#ifndef HFILE_FNAMES
-#   define HFILE_FNAMES
-#ifdef DF_CAPFNAMES
-#   define nhiopen   FNAME(HIOPEN)
-#   define nhclose   FNAME(HCLOSE)
-#   define nhxisdir  FNAME(HXISDIR)
-#   define nhxiscdir FNAME(HXISCDIR)
-#   define nhddontatexit FNAME(HDDONTATEXIT)
-#   define nhglibverc FNAME(HGLIBVERC)
-#   define nhgfilverc FNAME(HGFILVERC)
-#else
-#   define nhiopen   FNAME(hiopen)
-#   define nhclose   FNAME(hclose)
-#   define nhxisdir  FNAME(hxisdir)
-#   define nhxiscdir FNAME(hxiscdir)
-#   define nhddontatexit FNAME(hddontatexit)
-#   define nhglibverc FNAME(hglibverc)
-#   define nhgfilverc FNAME(hgfilverc)
-#endif /* DF_CAPFNAMES */
-#endif /* HFILE_FNAMES */
+#include "hproto_fortran.h"
 
 /*-----------------------------------------------------------------------------
  * Name:    hiopen
@@ -260,3 +241,51 @@ nhgfilverc(file_id, major_v, minor_v, release, string, len)
    return((intf)status);
 
 }
+/*-----------------------------------------------------------------------------
+ * Name:    hiishdf
+ * Purpose: call Hishdf function
+ * Inputs:  name: Name of the file 
+ *          namelen: length of name
+ * Returns: TRUE(1) on success, FALSE (-1) on failure
+ * Users:   HDF Fortran programmers
+ * Method:  Convert filename to C string, call Hishdf
+ *---------------------------------------------------------------------------*/
+
+FRETVAL(intf)
+nhiishdf(_fcd name,  intf * namelen)
+{
+    char       *fn;
+    intf        ret;
+
+    fn = HDf2cstring(name, (intn) *namelen);
+    if (!fn)
+	return(FAIL);
+    ret = (intf) Hishdf(fn);
+    HDfree(fn);
+    return (ret);
+}
+/*-----------------------------------------------------------------------------
+ * Name:    hconfinfc
+ * Purpose: call HCget_config_info
+ * Inputs:  coder_type - compression type
+ * Outputs: info       - flag to indicate compression status
+ *                       0 - compression is not available
+ *                       1 - only decoder found
+ *                       2 - both decoder and encoder are available
+ * Returns: SUCCEED (0)  on success, FALSE (-1) on failure
+ *---------------------------------------------------------------------------*/
+
+FRETVAL(intf)
+nhconfinfc (intf *coder_type,  intf * info)
+{
+    comp_coder_t coder_type_c;
+    uint32       info_c;
+    intn         status;
+
+    coder_type_c = (comp_coder_t) *coder_type;
+    status = HCget_config_info(coder_type_c, &info_c);
+    if (status == FAIL)
+	return(FAIL);
+    *info = (intf) info_c; 
+    return (status);
+}
