@@ -1,16 +1,17 @@
-C****************************************************************************
-C* NCSA HDF                                                                 *
-C* Software Development Group                                               *
-C* National Center for Supercomputing Applications                          *
-C* University of Illinois at Urbana-Champaign                               *
-C* 605 E. Springfield, Champaign IL 61820                                   *
-C*                                                                          *
-C* For conditions of distribution and use, see the accompanying             *
-C* hdf/COPYING file.                                                        *
-C*                                                                          *
-C****************************************************************************
+C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+C* Copyright by The HDF Group.                                               *
+C* Copyright by the Board of Trustees of the University of Illinois.         *
+C* All rights reserved.                                                      *
+C*                                                                           *
+C* This file is part of HDF.  The full HDF copyright notice, including       *
+C* terms governing use, modification, and redistribution, is contained in    *
+C* the files COPYING and Copyright.html.  COPYING can be found at the root   *
+C* of the source code distribution tree; Copyright.html can be found at      *
+C* http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+C* access to either file, you may request a copy from help@hdfgroup.org.     *
+C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 C
-C $Id: hfileff.f,v 1.8 1998/02/12 23:49:52 epourmal Exp $
+C $Id: hfileff.f 4964 2007-09-15 23:32:35Z epourmal $
 C
 C------------------------------------------------------------------------------
 C File:     hfileFf.f
@@ -121,3 +122,76 @@ C-----------------------------------------------------------------------------*/
      .                     len(string))
       return
       end
+C------------------------------------------------------------------------------
+C Name: hishdff
+C Purpose:  Identifies if the file "file_name" is an HDF file. 
+C Inputs:   file_name:  File name
+C Returns: TRUE (1) if successful, FALSE (0) otherwise.
+C Invokes: hiopen
+C----------------------------------------------------------------------------*/
+
+      integer function hishdff(filename)
+
+      character*(*) filename
+      integer       hiishdf
+
+      hishdff = hiishdf(filename, len(filename))
+      return
+      end
+C-----------------------------------------------------------------------------
+C Name: hestringf
+C Purpose: retrieves the error message associated with the specified error code 
+C Inputs:  error_code 
+C Outputs: error_message - string associated with the error code 
+C Retruns: SUCCEED (0) if successful and FAIL(-1) otherwise
+C-----------------------------------------------------------------------------*/
+
+      integer function hestringf(error_code, error_message)
+
+      integer error_code 
+      character*(*) error_message 
+      integer hestringc 
+
+      hestringf = hestringc(error_code, error_message,
+     .                      len(error_message))
+      return
+      end
+C-----------------------------------------------------------------------------
+C Name: heprntf
+C Purpose: prints values from the error stack 
+C Inputs:  filename - name of the output file; if length of the
+C          filename is 0, then output goes to stdout.  
+C          print_levels - number of levels to print 
+C Retruns: SUCCEED (0) if successful and FAIL(-1) otherwise
+C
+C Remarks: This routine always prints to the standard output.
+C-----------------------------------------------------------------------------*/
+
+      integer function heprntf(filename, print_levels)
+      integer print_levels 
+      character*(*) filename
+      
+      integer heprntc
+      heprntf = heprntc(filename, print_levels,len(filename))
+      return
+      end
+C-----------------------------------------------------------------------------
+C Name: hconfinf
+C Purpose: return info about configuration of a compression method
+C Inputs:  coder_type -  the compression type queried  
+C          info       -  flag to indicate compression status
+C                         0 - no compression found
+C                         1 - decoder only found
+C                         3 - both decoder and encoder found 
+C Retruns: SUCCEED (0) if successful and FAIL(-1) otherwise
+C
+C Currently this routine is used with SZIP compression only 
+C-----------------------------------------------------------------------------*/
+
+      integer function hconfinf(coder_type, info)
+      integer coder_type, info
+
+      integer hconfinfc
+      hconfinf = hconfinfc(coder_type, info)
+      return
+      end
