@@ -1,17 +1,17 @@
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
-
-/* $Id: hkit.h,v 1.15 1996/10/10 18:43:27 koziol Exp $ */
+/* $Id: hkit.h 5467 2010-09-25 14:19:19Z bmribler $ */
 
 /*+ hkit.h
    ***  private header file for hkit routines
@@ -33,11 +33,7 @@ typedef struct tag_descript_t
 tag_descript_t;
 
 /* stringizing macro */
-#if defined MIPSEL | defined KNRSUN | defined __SUNPRO_C
 #define string(x) #x
-#else
-#define string(x) "x"
-#endif /* MIPSEL */
 
 /*  NOTE:
  *        Please keep tag descriptions <= 30 characters - a
