@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.2 $";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* $Id: linklist.c,v 1.2 1996/05/16 18:42:05 koziol Exp $ */
+/* $Id: linklist.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*
 FILE
@@ -83,10 +84,6 @@ list_head_t *HULcreate_list(HULfind_func_t find_func    /* IN: object comparison
     CONSTR(FUNC, "HULcreate_list");	/* for HERROR */
     list_head_t *ret_value=NULL;     /* ptr to the linked list "head" node */
 
-#ifdef HAVE_PABLO
-    TRACE_ON(HUL_mask, ID_HULcreate_list);
-#endif /* HAVE_PABLO */
-
     HEclear();
 
     /* Allocate the head information */
@@ -110,10 +107,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(HUL_mask, ID_HULcreate_list);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end HULcreate_list() */
 
@@ -139,10 +132,6 @@ intn HULdestroy_list(list_head_t *lst    /* IN: list to destroy */
         *next_node;                 /* next node in the list */
     intn ret_value=SUCCEED;         /* return value */
 
-#ifdef HAVE_PABLO
-    TRACE_ON(HUL_mask, ID_HULdestroy_list);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if(lst==NULL)
         HGOTO_ERROR(DFE_ARGS,FAIL);
@@ -166,10 +155,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(HUL_mask, ID_HULdestroy_list);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end HULdestroy_list() */
 
@@ -194,10 +179,6 @@ intn HULadd_node(list_head_t *lst,  /* IN: list to modify */
     node_info_t *new_node;          /* new node to insert into the list */
     intn ret_value=SUCCEED;         /* return value */
 
-#ifdef HAVE_PABLO
-    TRACE_ON(HUL_mask, ID_HULadd_node);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if(lst==NULL || obj==NULL)
         HGOTO_ERROR(DFE_ARGS,FAIL);
@@ -248,10 +229,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(HUL_mask, ID_HULadd_node);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end HULadd_node() */
 
@@ -275,10 +252,6 @@ VOIDP HULsearch_node(list_head_t *lst,  /* IN: list to search */
     node_info_t *curr_node;         /* current node we are on */
     VOIDP ret_value=NULL;           /* default return value */
 
-#ifdef HAVE_PABLO
-    TRACE_ON(HUL_mask, ID_HULsearch_node);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if(lst==NULL || srch_func==NULL || key==NULL)
         HGOTO_ERROR(DFE_ARGS,NULL);
@@ -297,10 +270,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(HUL_mask, ID_HULsearch_node);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end HULsearch_node() */
 
@@ -322,10 +291,6 @@ VOIDP HULfirst_node(list_head_t *lst   /* IN: list to search */
     CONSTR(FUNC, "HULfirst_node");	/* for HERROR */
     VOIDP ret_value=NULL;           /* default return value */
 
-#ifdef HAVE_PABLO
-    TRACE_ON(HUL_mask, ID_HULfirst_node);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if(lst==NULL)
         HGOTO_ERROR(DFE_ARGS,NULL);
@@ -343,10 +308,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(HUL_mask, ID_HULfirst_node);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end HULfirst_node() */
 
@@ -367,10 +328,6 @@ VOIDP HULnext_node(list_head_t *lst   /* IN: list to search */
     CONSTR(FUNC, "HULnext_node");	/* for HERROR */
     VOIDP ret_value=NULL;           /* default return value */
 
-#ifdef HAVE_PABLO
-    TRACE_ON(HUL_mask, ID_HULnext_node);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if(lst==NULL)
         HGOTO_ERROR(DFE_ARGS,NULL);
@@ -389,10 +346,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(HUL_mask, ID_HULnext_node);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end HULnext_node() */
 
@@ -418,10 +371,6 @@ VOIDP HULremove_node(list_head_t *lst,  /* IN: list to modify */
         *prev_node;                 /* previous node we looked at */
     VOIDP ret_value=NULL;           /* default return value */
 
-#ifdef HAVE_PABLO
-    TRACE_ON(HUL_mask, ID_HULremove_node);
-#endif /* HAVE_PABLO */
-
     HEclear();
     if(lst==NULL || srch_func==NULL || key==NULL)
         HGOTO_ERROR(DFE_ARGS,NULL);
@@ -449,10 +398,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(HUL_mask, ID_HULremove_node);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* end HULremove_node() */
 
