@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)1.8";
+static char RcsId[] = "@(#)$Revision: 4932 $";
 #endif
 
-/* maldebug.c,v 1.8 1996/03/28 21:57:38 koziol Exp */
+/* $Id: maldebug.c 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*----------------------------------------------------------------------
  *
@@ -310,16 +311,6 @@ mem_HDrealloc(
     p->mh_tag = ~MEMTAG;
     mem_size -= p->mh_size;
 
-#ifdef QAK
-/* Invalidate the block of memory to be free'd */
-/* ------------------------------------------- */
-#if defined(MEM_COMP_FREE)
-    q = (unsigned char *) ptr;
-    for (i = 0; i < p->mh_size; i++)
-        q[i] = ~q[i];
-#endif
-#endif
-
 #if defined(MEM_WHERE)
     mem_list_delete(p);     /* Remove block from list */
 #endif
@@ -666,7 +657,4 @@ mem_tag_err(void *p, int type, char *func, char *fil, int lin)
     Mem_Display(stdaux);
 #endif
 #endif
-#ifdef QAK
-    exit(1);
-#endif
 }   /* end mem_tag_err() */
