@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)1.38";
+static char RcsId[] = "@(#)$Revision: 6043 $";
 #endif
 
-/* tbbt.c,v 1.38 1996/06/24 21:42:07 acheng Exp */
+/* $Id: tbbt.c 6043 2014-01-21 21:09:03Z acheng $ */
 
 /* "tbbt.c" -- Routines for using threaded, balanced, binary trees. */
 /* Extended from (added threads to) Knuth 6.2.3, Algorithm A (AVL trees) */
@@ -27,8 +28,8 @@ static char RcsId[] = "@(#)1.38";
 #define   Alloc(cnt,typ)   (typ *) HDmalloc( (cnt) * sizeof(typ) )
 #define   Free(x)           (HDfree((VOIDP)x))
 
-# define   KEYcmp(k1,k2,a)   (  (NULL!=compar) ? (*compar)( k1, k2, a)         \
-                             : HDmemcmp( k1, k2, 0<(a) ? (a) : HDstrlen(k1) )  )
+# define   KEYcmp(k1,k2,a) ((NULL!=compar) ? (*compar)( k1, k2, a) \
+                 : HDmemcmp( k1, k2, 0<(a) ? (a) : (intn)HDstrlen(k1) )  )
 
 VOID        tbbt1dump
             (TBBT_NODE * node, intn method);
@@ -115,6 +116,7 @@ tbbtprev(TBBT_NODE * node)
 }
 
 /* tbbtfind -- Look up a node in a tree based on a key value */
+/* tbbtffind is based on this routine - fix bugs in both places! */
 /* Returns a pointer to the found node (or NULL) */
 TBBT_NODE  *
 tbbtfind(TBBT_NODE * root, VOIDP key,
@@ -142,6 +144,59 @@ tbbtfind(TBBT_NODE * root, VOIDP key,
     return ((0 == cmp) ? ptr : NULL);
 }
 
+/* tbbtffind -- Look up a node in a tree based on a key value */
+/* This routine is based on tbbtfind (fix bugs in both places!) */
+/* Returns a pointer to the found node (or NULL) */
+static TBBT_NODE  *
+tbbtffind(TBBT_NODE * root, VOIDP key, uintn fast_compare, TBBT_NODE ** pp)
+{
+    TBBT_NODE  *ptr = root;
+    TBBT_NODE  *parent = NULL;
+    intn        cmp = 1;
+
+    switch(fast_compare)
+      {
+        case TBBT_FAST_UINT16_COMPARE:
+            if (ptr)
+              {
+                  intn        side;
+
+                  while (0 != (cmp = (*(uint16 *)key - *(uint16 *)ptr->key)))
+                    {
+                        parent = ptr;
+                        side = (cmp < 0) ? LEFT : RIGHT;
+                        if (!HasChild(ptr, side))
+                            break;
+                        ptr = ptr->link[side];
+                    }
+              }
+            if (NULL != pp)
+                *pp = parent;
+            return ((0 == cmp) ? ptr : NULL);
+
+        case TBBT_FAST_INT32_COMPARE:
+            if (ptr)
+              {
+                  intn        side;
+
+                  while (0 != (cmp = (*(int32 *)key - *(int32 *)ptr->key)))
+                    {
+                        parent = ptr;
+                        side = (cmp < 0) ? LEFT : RIGHT;
+                        if (!HasChild(ptr, side))
+                            break;
+                        ptr = ptr->link[side];
+                    }
+              }
+            if (NULL != pp)
+                *pp = parent;
+            return ((0 == cmp) ? ptr : NULL);
+
+        default:
+            return(NULL);
+    } /* end switch */
+} /* tbbtffind() */
+
 /* tbbtdfind -- Look up a node in a "described" tree based on a key value */
 /* Returns a pointer to the found node (or NULL) */
 TBBT_NODE  *
@@ -149,7 +204,10 @@ tbbtdfind(TBBT_TREE * tree, VOIDP key, TBBT_NODE ** pp)
 {
     if (tree == NULL)
         return (NULL);
-    return (tbbtfind(tree->root, key, tree->compar, tree->cmparg, pp));
+    if(tree->fast_compare!=0)
+        return (tbbtffind(tree->root, key, tree->fast_compare, pp));
+    else
+        return (tbbtfind(tree->root, key, tree->compar, tree->cmparg, pp));
 }
 
 /* tbbtless -- Find a node in a tree which is less than a key, */
@@ -235,7 +293,7 @@ tbbtindx(TBBT_NODE * root, int32 indx)
       else if (HasChild(ptr, RIGHT))
         { /* subtract children count from leftchild plus current node when
              we descend into a right branch */
-          indx -= LeftCnt(ptr) + 1 ;  
+          indx -= (int32)(LeftCnt(ptr) + 1);  
           ptr = ptr->Rchild;
         }
       else
@@ -277,7 +335,7 @@ swapkid(TBBT_NODE ** root, TBBT_NODE * ptr, intn side)
     deep[2] = (deep[1] = 0) + Delta(kid, side);
     deep[0] = Max(0, deep[2]) + 1 - Delta(ptr, side);
     kid->Parent = ptr->Parent;
-    ptrflg = SetFlags(ptr, side, deep[0],
+    ptrflg = (TBBT_FLAG)SetFlags(ptr, side, deep[0],
                   HasChild(ptr, Other(side)) && HasChild(kid, Other(side)));
     plcnt = LeftCnt(ptr);
     prcnt = RightCnt(ptr);
@@ -307,13 +365,8 @@ swapkid(TBBT_NODE ** root, TBBT_NODE * ptr, intn side)
       }
     ptr->Parent = kid;
     kid->link[Other(side)] = ptr;
-#if defined (MAC) || defined (macintosh) || defined(__MWERKS__) || defined (SYMANTEC_C) /* Macro substitution limit on Mac */
-    kid->flags = SetFlags(kid, (1 + 2 - (side)),
+    kid->flags = (TBBT_FLAG)SetFlags(kid, Other(side),
                         deep[2] - 1 - Max(deep[0], 0), HasChild(kid, side));
-#else  /* !macintosh */
-    kid->flags = SetFlags(kid, Other(side),
-                        deep[2] - 1 - Max(deep[0], 0), HasChild(kid, side));
-#endif /* !macintosh */
 
     /* update leaf counts */
     if (side == LEFT)
@@ -397,20 +450,21 @@ balance(TBBT_NODE ** root, TBBT_NODE * ptr, intn side, intn added)
                   {     /* Just became unbalanced: */
                       if (ptr->link[Other(side)] != NULL && ptr->link[Other(side)]->Parent == ptr)
                         {
-                            ptr->flags |= TBBT_HEAVY(Other(side));  /* Other side longer */
+                            ptr->flags |= (TBBT_FLAG)TBBT_HEAVY(Other(side));  /* Other side longer */
                             if (ptr->Parent)
-                                if (ptr->Parent->Rchild == ptr)     /* we're the right child */
+                                if (ptr->Parent->Rchild == ptr) {     /* we're the right child */
                                     if (Heavy(ptr->Parent, RIGHT) && LeftCnt(ptr->Parent) == 1)
                                         deeper = 0;
                                     else
                                         /* we're the left child */ if (Heavy(ptr->Parent, LEFT))
                                         if (ptr->Parent->Rchild && !UnBal(ptr->Parent->Rchild))
                                             deeper = 0;
+                                }
                         }
                   }
                 else
                   {     /* Just became unbalanced: */
-                      ptr->flags |= TBBT_HEAVY(side);   /* 0<deeper: Our side longer */
+                      ptr->flags |= (TBBT_FLAG)TBBT_HEAVY(side);   /* 0<deeper: Our side longer */
                   }     /* end else */
             }
           if (ptr->Parent)
@@ -472,7 +526,7 @@ balance(TBBT_NODE ** root, TBBT_NODE * ptr, intn side, intn added)
 /* Returns pointer to inserted node (or NULL) */
 TBBT_NODE  *
 tbbtins(TBBT_NODE ** root, VOIDP item, VOIDP key, intn (*compar)
-        (VOIDP k1, VOIDP k2, intn arg), intn arg)
+        (VOIDP /* k1 */, VOIDP /* k2 */, intn /* arg */), intn arg)
 {
     intn        cmp;
     TBBT_NODE  *ptr, *parent;
@@ -623,7 +677,7 @@ tbbtrem(TBBT_NODE ** root, TBBT_NODE * node, VOIDP *kp)
     if (!UnBal(leaf))
       {     /* Case 2: `leaf' has no children: */
           par->link[side] = leaf->link[side];
-          par->flags &= ~(TBBT_INTERN | TBBT_HEAVY(side));
+          par->flags &= (TBBT_FLAG)(~(TBBT_INTERN | TBBT_HEAVY(side)));
       }
     else
       {     /* Case 1: `leaf' has one child: */
@@ -659,7 +713,7 @@ tbbtrem(TBBT_NODE ** root, TBBT_NODE * node, VOIDP *kp)
 /* tbbtdmake - Allocate a new tree description record for an empty tree */
 /* Returns a pointer to the description record */
 TBBT_TREE  *
-tbbtdmake(intn (*cmp) (VOIDP k1, VOIDP k2, intn arg), intn arg)
+tbbtdmake(intn (*cmp) (VOIDP /* k1 */, VOIDP /* k2 */, intn /* arg */), intn arg, uintn fast_compare)
 {
     TBBT_TREE  *tree = Alloc(1, TBBT_TREE);
 
@@ -667,6 +721,7 @@ tbbtdmake(intn (*cmp) (VOIDP k1, VOIDP k2, intn arg), intn arg)
         return (NULL);
     tree->root = NULL;
     tree->count = 0;
+    tree->fast_compare=fast_compare;
     tree->compar = cmp;
     tree->cmparg = arg;
     return (tree);
@@ -706,7 +761,7 @@ tbbtfree(TBBT_NODE ** root, VOID(*fd) (VOIDP item), VOID(*fk) (VOIDP key))
 
 /* tbbtfree() - Free an entire tree not allocated with tbbtdmake(). */
 VOID
-tbbtfree(TBBT_NODE ** root, VOID(*fd) (VOIDP item), VOID(*fk) (VOIDP key))
+tbbtfree(TBBT_NODE ** root, VOID(*fd) (VOIDP /* item */), VOID(*fk) (VOIDP /* key */))
 {
     TBBT_NODE  *par, *node = *root;
 
@@ -872,7 +927,7 @@ tbbt_dump(TBBT_TREE *ptree, VOID (*key_dump)(VOID *,VOID *), intn method)
 	TBBT_TREE  *tree;
 
 	tree = (TBBT_TREE *) ptree;
-	printf("TBBT-tree dump  %x:\n\n",ptree);
+	printf("TBBT-tree dump  %p:\n\n",ptree);
 	printf("capacity = %ld\n",(long)tree->count);
 	printf("\n");
 	tbbt_dumpNode(tree->root,key_dump, method);
@@ -881,7 +936,7 @@ tbbt_dump(TBBT_TREE *ptree, VOID (*key_dump)(VOID *,VOID *), intn method)
 
 /* Always returns NULL */
 TBBT_TREE  *
-tbbtdfree(TBBT_TREE * tree, VOID(*fd) (VOIDP item), VOID(*fk) (VOIDP key))
+tbbtdfree(TBBT_TREE * tree, VOID(*fd) (VOIDP /* item */), VOID(*fk) (VOIDP /* key */))
 {
     if (tree == NULL)
         return (NULL);
@@ -898,7 +953,7 @@ tbbtcount(TBBT_TREE * tree)
     if (tree == NULL)
         return (-1);
     else
-        return (tree->count);
+        return ((long)tree->count);
 }
 
 /******************************************************************************
