@@ -1,16 +1,17 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: vg.h,v 1.52 1998/02/10 18:59:14 bmribler Exp $ */
+/* $Id: vg.h 4932 2007-09-07 17:17:23Z bmribler $ */
 
 /*****************************************************************************
 *
@@ -66,7 +67,7 @@
 
 /* Only include the library header if the VSET_INTERFACE macro is defined */
 #ifdef VSET_INTERFACE
-#include <vgint.h>          /* Library VSet information header */
+#include "vgint.h"          /* Library VSet information header */
 #endif /* VSET_INTERFACE */
 
 #endif                          /* _VG_H */
