@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.40 $";
+static char RcsId[] = "@(#)$Revision: 5737 $";
 #endif
 
-/* $Id: vgf.c,v 1.40 1998/02/09 21:54:13 epourmal Exp $ */
+/* $Id: vgf.c 5737 2012-01-06 04:52:28Z brtnfld $ */
 
 /*-----------------------------------------------------------------------------
   FUNCTION NAMEING CONVENTION:(For the most part true)
@@ -46,6 +47,7 @@ static char RcsId[] = "@(#)$Revision: 1.40 $";
 
 #define VSET_INTERFACE
 #include "hdf.h"
+#include "hproto_fortran.h"
 
 /*
    **  remove trailing blanks from a string. input argument is a  string
@@ -706,22 +708,24 @@ nvfnflds(intf * vkey)
 /* ------------------------------------------------------------------ */
 /*
    **  get the name of a given field in a vdata
-   **  related: VFfieldname--vffname--
+   **  related: VFfieldname--vffname--vffnamec
  */
 
 FRETVAL(intf)
-nvffname(intf * vkey, intf * index, _fcd fname)
+nvffnamec(intf * vkey, intf * index, _fcd fname, intf *len)
 {
-    char *fieldname;
-
+    char *fieldname = NULL;
+    
     if((fieldname=VFfieldname((int32)*vkey,(int32)*index))!=NULL)
       {
-        HDstrcpy(_fcdtocp(fname),fieldname);
+       /* HDstrcpy(_fcdtocp(fname),fieldname);*/
+        HDpackFstring(fieldname, _fcdtocp(fname), (intn) *len);
+        /* HDfree(fieldname); */
         return(SUCCEED);
       } /* end if */
     else
         return(FAIL);
-}   /* vffname */
+}   /* vffnamec */
 
 /* ------------------------------------------------------------------ */
 /*
@@ -1451,3 +1455,173 @@ nvdtrc(intf * vkey, intf * tag, intf * ref)
        HDfree(class_name);
        return(ret);
 } 
+/*------------------------------------------------------------------------
+ *       Name:      vscsetblsz
+ *       Purpose:   calls VSsetblocksize
+ *       Inputs:    id    -  vdata identifier
+ *                  block_size - size of the block
+ *       Returns:   0 if succeeds, -1 if fails
+ *       Users:     HDF Fortran programmers
+ ---------------------------------------------------------------------*/
+     FRETVAL (intf)
+#ifdef PROTOTYPE
+       nvscsetblsz( intf *id , intf *block_size)
+#else
+       nvscsetblsz (id, block_size)
+               intf   *id;
+               intf   *block_size;
+#endif /* PROTOTYPE */
+
+{
+       intf  ret = -1;
+       intn c_ret;	
+
+       c_ret = VSsetblocksize( *id, *block_size);
+       if(c_ret == 0) ret = 0;
+       return(ret);
+} 
+/*------------------------------------------------------------------------
+ *       Name:      vscsetnmbl
+ *       Purpose:   calls VSsetnumblocks
+ *       Inputs:    id    -  vdata identifier
+ *                  num_blocks - number of blocks
+ *       Returns:   0 if succeeds, -1 if fails
+ *       Users:     HDF Fortran programmers
+ ---------------------------------------------------------------------*/
+     FRETVAL (intf)
+#ifdef PROTOTYPE
+       nvscsetnmbl( intf *id , intf *num_blocks)
+#else
+       nvscsetnmbl (id, num_blocks)
+               intf   *id;
+               intf   *num_blocks;
+#endif /* PROTOTYPE */
+
+{
+       intf  ret;
+       intn  c_ret;
+
+       c_ret = VSsetnumblocks( *id, *num_blocks);
+       if(c_ret == 0) ret = 0;
+       return(ret);
+} 
+/*------------------------------------------------------------------------
+ *       Name:      vscgblinfo
+ *       Purpose:   calls VSgetblockinfo
+ *       Inputs:    id    -  vdata identifier
+ *                  block_size - size of the block
+ *                  num_blocks - number of blocks
+ *       Returns:   0 if succeeds, -1 if fails
+ *       Users:     HDF Fortran programmers
+ ---------------------------------------------------------------------*/
+     FRETVAL (intf)
+#ifdef PROTOTYPE
+       nvscgblinfo( intf *id , intf *block_size, intf *num_blocks)
+#else
+       nvscgblinfo (id, block_size, num_blocks)
+               intf   *id;
+               intf   *block_size; 
+               intf   *num_blocks;
+#endif /* PROTOTYPE */
+
+{
+       intf  ret = -1;
+        intn c_ret;
+	int32 c_block_size;
+        int32 c_num_blocks;
+
+       c_ret = VSgetblockinfo( *id, &c_block_size, &c_num_blocks);
+       if (c_ret == 0) {
+       		*block_size = c_block_size;
+       	        *num_blocks = c_num_blocks;
+       	      	ret = 0;
+       }
+       return(ret);
+} 
+/*------------------------------------------------------------------------
+ *       Name:      vcgvgrp
+ *       Purpose:   calls Vgetvgroups
+ *       Inputs:    id       - vdata identifier
+ *                  start_vg - size of the block
+ *                  vg_count - number of blocks
+ *       Outputs:   refarray - Array to hold reference numbers 
+ *                             of retrieved vgroups
+ *       Returns:   0 if succeeds, -1 if fails
+ *       Users:     HDF Fortran programmers
+ ---------------------------------------------------------------------*/
+     FRETVAL (intf)
+#ifdef PROTOTYPE
+       nvcgvgrp(intf *id, intf *start_vg, intf *vg_count, intf *refarray)
+#else
+       nvcgvgrp(id, start_vg, vg_count, refarray)
+               intf   *id;
+               intf   *start_vg; 
+               intf   *vg_count;
+	       intf   *refarray;
+#endif /* PROTOTYPE */
+
+{
+       intf  ret=-1;
+       uintn ii;
+       uint16 *c_refarray;
+
+       if(*vg_count == -1) {
+	 ret = (intf)Vgetvgroups((int32)*id, (uintn)*start_vg, 0, NULL );
+       }
+       else {
+	 c_refarray = (uint16 *)HDmalloc(sizeof(uint16)*(uintn)*vg_count);
+	 ret = (intf)Vgetvgroups((int32)*id, (uintn)*start_vg, (uintn)*vg_count, c_refarray );
+
+	 /* copy C refarray to the fortran refarray, converting uint16 to intf type */
+	 for (ii = 0; ii < (uintn)*vg_count; ii++)
+	   refarray[ii] = (intf)c_refarray[ii];
+	 
+	 if (c_refarray != NULL)
+	   HDfree(c_refarray);
+       }
+       return(ret);
+} 
+/*------------------------------------------------------------------------
+ *       Name:      vscgvdatas
+ *       Purpose:   calls  VSgetvdatas
+ *       Inputs:    id       - File identifier returned by Hopen or vgroup 
+ *                             identifier returned by Vattach
+ *                  start_vd - Vdata number to start retrieving at
+ *                  vd_count - Number of vdatas to be retrieved
+ *       Outputs:   refarray - Array to hold reference numbers of 
+ *                             retrieved vdatas 
+ *       Returns:   0 if succeeds, -1 if fails
+ *       Users:     HDF Fortran programmers
+ ---------------------------------------------------------------------*/
+     FRETVAL (intf)
+#ifdef PROTOTYPE
+       nvscgvdatas(intf *id, intf *start_vd, intf *vd_count, intf *refarray)
+#else
+       nvscgvdatas(id, start_vd, vd_count, refarray)
+               intf   *id;
+               intf   *start_vd; 
+               intf   *vd_count;
+	       intf   *refarray;
+#endif /* PROTOTYPE */
+
+{
+       intf   ret=-1;
+       uintn ii;
+       uint16 *c_refarray;
+
+       if(*vd_count == -1) {
+	 ret = (intf)VSgetvdatas((int32)*id, (uintn)*start_vd, 0, NULL );
+       }
+       else {
+	 c_refarray = (uint16 *)HDmalloc(sizeof(uint16)*(uintn)*vd_count);
+	 ret = (intf)VSgetvdatas((int32)*id, (uintn)*start_vd, (uintn)*vd_count, c_refarray );
+         /* copy C refarray to the fortran refarray, converting uint16 to intf type */
+	 for (ii = 0; ii < (uintn)*vd_count; ii++)
+	   refarray[ii] = (intf)c_refarray[ii];
+	 
+	 if (c_refarray != NULL)
+	   HDfree(c_refarray);
+       }
+
+       return(ret);
+} 
