@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.74 $";
+static char RcsId[] = "@(#)$Revision: 6026 $";
 #endif
 
-/* $Id: vio.c,v 1.74 1998/02/07 22:28:57 koziol Exp $ */
+/* $Id: vio.c 6026 2014-01-16 15:16:16Z bmribler $ */
 
 /*****************************************************************************
  file - vio.c
@@ -415,10 +416,6 @@ vpackvs(VDATA * vs,  /* IN/OUT: */
     uint8 *bb = NULL;
     intn  ret_value = SUCCEED;
 
-#ifdef HAVE_PABLO
-    TRACE_ON(V_mask, ID_vpackvs);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -523,10 +520,6 @@ done:
 #endif /* LATER */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(V_mask, ID_vpackvs);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* vpackvs */
 
@@ -554,10 +547,6 @@ vunpackvs(VDATA * vs, /* IN/OUT: */
     int32       ret_value = SUCCEED;
     CONSTR(FUNC, "vunpackvs");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(V_mask, ID_vunpackvs);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -709,11 +698,7 @@ done:
 
     } /* end if */
 
-  /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(V_mask, ID_vunpackvs);
-#endif /* HAVE_PABLO */
-
+	  /* Normal function cleanup */
   return ret_value;
 }   /* vunpackvs */
 
@@ -905,9 +890,6 @@ VSattach(HFILEID f,             /* IN: file handle */
     int32      ret_value = FAIL;
     CONSTR(FUNC, "VSattach");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(VS_mask, ID_VSattach);
-#endif /* HAVE_PABLO */
     /* clear error stack */
     HEclear();
 
@@ -999,8 +981,18 @@ VSattach(HFILEID f,             /* IN: file handle */
         if (acc_mode == 'r')
           {     /* reading an existing vdata */
               /* this vdata is already attached for 'r', ok to do so again */
+	      /* then reset the read position to the beginning of the vdata */
               if (w->nattach && w->vs->access == 'r')
+		{
+		  accrec_t *access_rec;	/* access record */
+
                   w->nattach++;
+
+		  /* get the access_rec pointer to reset position */
+		  if ((access_rec = HAatom_object(w->vs->aid)) == NULL)
+		      HGOTO_ERROR(DFE_ARGS, FAIL);
+		  access_rec->posn = 0;	/* to fix bugzilla #486 - BMR, Dec, 05 */
+		}
               else
                 {
                   vs = w->vs;
@@ -1052,9 +1044,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(VS_mask, ID_VSattach);
-#endif /* HAVE_PABLO */
 
   return ret_value;
 }	/* VSattach */
@@ -1094,10 +1083,6 @@ VSdetach(int32 vkey /* IN: vdata key? */)
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "VSdetach");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(VS_mask, ID_VSdetach);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1123,6 +1108,7 @@ VSdetach(int32 vkey /* IN: vdata key? */)
             { /* end access to vdata */
               if (Hendaccess(vs->aid) == FAIL)
                   HGOTO_ERROR(DFE_INTERNAL, FAIL);
+	      vs->aid = FAIL;
 
               /* remove from atom list */
               if(HAremove_atom(vkey)==NULL)
@@ -1201,6 +1187,7 @@ VSdetach(int32 vkey /* IN: vdata key? */)
           /* end access to vdata */
           if (Hendaccess(vs->aid) == FAIL)
               HGOTO_ERROR(DFE_INTERNAL, FAIL);
+	  vs->aid = FAIL;
 
           /* remove vdata from atom list */
           if(HAremove_atom(vkey)==NULL)
@@ -1215,10 +1202,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(VS_mask, ID_VSdetach);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* VSdetach */
 
@@ -1241,10 +1224,6 @@ VSappendable(int32 vkey, /* IN: vdata key */
     int32      ret_value = SUCCEED;
     CONSTR(FUNC, "VSappendable");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(VS_mask, ID_VSappendable);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1276,10 +1255,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(VS_mask, ID_VSappendable);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSappendable */
 
@@ -1307,10 +1282,6 @@ VSgetid(HFILEID f,  /* IN: file handle */
     int32        ret_value = SUCCEED;
     CONSTR(FUNC, "VSgetid");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(VS_mask, ID_VSgetid);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1359,10 +1330,6 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(VS_mask, ID_VSgetid);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }   /* VSgetid */
 
@@ -1590,10 +1557,6 @@ VSdelete(int32 f,    /* IN: file handle */
     int32       ret_value = SUCCEED;
     CONSTR(FUNC, "VSdelete");
 
-#ifdef HAVE_PABLO
-    TRACE_ON(VS_mask, ID_VSdelete);
-#endif /* HAVE_PABLO */
-
     /* clear error stack */
     HEclear();
 
@@ -1631,9 +1594,5 @@ done:
     } /* end if */
 
   /* Normal function cleanup */
-#ifdef HAVE_PABLO
-    TRACE_OFF(VS_mask, ID_VSdelete);
-#endif /* HAVE_PABLO */
-
   return ret_value;
 }	/* VSdelete */
