@@ -1,14 +1,15 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
    FILE
@@ -30,17 +31,17 @@
    10/19/93 - Started coding.
  */
 
-/* $Id: bitio.c,v 1.20 1996/11/11 20:39:46 koziol Exp $ */
+/* $Id: bitio.c 5210 2009-08-21 20:27:12Z brtnfld $ */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.20 $";
+static char RcsId[] = "@(#)$Revision: 5210 $";
 #endif
 
 #include "tproto.h"
 #include <time.h>
 
 #define TESTFILE_NAME "tbitio.hdf"
-#define DATAFILE_NAME "bitio.dat"
+#define DATAFILE_NAME "test_files/bitio.dat"
 
 /* Last ditch attempt to define this value... */
 #ifndef UINT_MAX
@@ -66,6 +67,8 @@ static char RcsId[] = "@(#)$Revision: 1.20 $";
 #define BITIO_REF_1     1500
 #define BITIO_TAG_2     2500
 #define BITIO_REF_2     2500
+#define BITIO_TAG_3     3500
+#define BITIO_REF_3     3500
 
 static uint8  outbuf[BUFSIZE],  inbuf[DATASIZE];
 
@@ -107,49 +110,41 @@ test_bitio_write(void)
       }     /* end for */
 
     fid = Hopen(TESTFILE_NAME, DFACC_CREATE, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
+
     bitid1 = Hstartbitwrite(fid, BITIO_TAG_1, BITIO_REF_1, 16);
-    CHECK(bitid1, FAIL, "Hstartbitwrite");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitwrite");
+
     ret = Hbitappendable(bitid1);
     RESULT("Hbitappendable");
 
     for (i = 0; i < BUFSIZE; i++)
       {
           ret = Hbitwrite(bitid1, (intn)outbuf[i], (uint32) outbuf2[i]);
-#ifdef TESTING
-          printf("outbuf[%d]=%u, outbuf2[%d]=%u, totbits[%d]=%u\n", i, outbuf[i], i, outbuf2[i], i, totbits[i]);
-#endif
-          VERIFY((uint8) ret, outbuf[i], "Hbitwrite");
+          VERIFY_VOID((uint8) ret, outbuf[i], "Hbitwrite");
       }     /* end for */
 
     ret = Hendbitaccess(bitid1, 0);
     RESULT("Hbitendaccess");
 
     bitid1 = Hstartbitread(fid, BITIO_TAG_1, BITIO_REF_1);
-    CHECK(bitid1, FAIL, "Hstartbitread");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitread");
 
     for (i = 0; i < BUFSIZE; i++)
       {
           ret = Hbitread(bitid1, (intn)outbuf[i], &inbuf2[i]);
-#ifdef TESTING
-          printf("outbuf[%d]=%u, inbuf2[%d]=%u, totbits[%d]=%u\n", i, outbuf[i], i, inbuf2[i], i, totbits[i]);
-#endif
-          VERIFY((uint8) ret, outbuf[i], "Hbitread");
+          VERIFY_VOID((uint8) ret, outbuf[i], "Hbitread");
       }     /* end for */
     if (HDmemcmp(outbuf2, inbuf2, sizeof(int32) * BUFSIZE))
       {
           printf("Error in writing/reading bit I/O data\n");
           HEprint(stdout, 0);
-#ifdef TESTING
-          for (i = 0; i < BUFSIZE; i++)
-              if (outbuf2[i] != inbuf2[i])
-                  printf("outbuf[%d]=%u, outbuf2[%d]=%u inbuf2[%d]=%u, totbits[%d]=%u\n", i, outbuf[i], i, outbuf2[i], i, inbuf2[i], i, totbits[i]);
-#endif
           num_errs++;
       }     /* end for */
 
     ret = Hendbitaccess(bitid1, 0);
     RESULT("Hbitendaccess");
+
     ret = Hclose(fid);
     RESULT("Hclose");
 }   /* test_bitio_write() */
@@ -164,30 +159,42 @@ test_bitio_read(void)
     uint32      tempbuf;
     intn        i;
     uint8      *test_ptr;
+    char        datafile[512] = "";
+    char       *srcdir = getenv("srcdir");
 
     SEED((uintn) time(NULL));
 
     MESSAGE(6, printf("Testing bitio read routines\n");
         );
 
-    fid = Hopen(DATAFILE_NAME, DFACC_READ, 0);
-    CHECK(fid, FAIL, "Hopen");
+    /* Generate the correct name for the test file, by prepending the source path */
+    if (srcdir && ((strlen(srcdir) + strlen(DATAFILE_NAME) + 1) < sizeof(datafile))) {
+        strcpy(datafile, srcdir);
+        strcat(datafile, "/");
+    }
+    strcat(datafile, DATAFILE_NAME);
+
+    fid = Hopen(datafile, DFACC_READ, 0);
+    CHECK_VOID(fid, FAIL, "Hopen");
+
     ret = Hgetelement(fid, DATA_TAG_1, DATA_REF_1, inbuf);
     RESULT("Hgetelement");
+
     ret = Hclose(fid);
     RESULT("Hclose");
 
     MESSAGE(8, printf("Reading 8 bits at a time\n");
         );
-    fid = Hopen(DATAFILE_NAME, DFACC_READ, 0);
-    CHECK(fid, FAIL, "Hopen");
+    fid = Hopen(datafile, DFACC_READ, 0);
+    CHECK_VOID(fid, FAIL, "Hopen");
+
     bitid1 = Hstartbitread(fid, DATA_TAG_1, DATA_REF_1);
-    CHECK(bitid1, FAIL, "Hstartbitread");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitread");
 
     for (i = 0; i < DATASIZE; i++)
       {
           ret = Hbitread(bitid1, 8, &inbuf2[i]);
-          VERIFY(ret, 8, "Hbitread");
+          VERIFY_VOID(ret, 8, "Hbitread");
       }     /* end for */
     ret = Hendbitaccess(bitid1, 0);
     RESULT("Hbitendaccess");
@@ -205,19 +212,19 @@ test_bitio_read(void)
     MESSAGE(8, printf("Read random # of bits at a time\n");
         );
     bitid1 = Hstartbitread(fid, DATA_TAG_1, DATA_REF_1);
-    CHECK(bitid1, FAIL, "Hstartbitread");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitread");
 
     /* read in random #'s of bits */
     for (i = 0; i < DATASIZE / (NUM_BITS / 8); i++)
       {
           inbits = ((RAND() >> 4) % NUM_BITS) + 1;  /* number of bits to input */
           ret = Hbitread(bitid1, inbits, &inbuf2[i]);
-          VERIFY(ret, inbits, "Hbitread");
+          VERIFY_VOID(ret, inbits, "Hbitread");
           if (inbits < NUM_BITS)
             {   /* if we've already grabbed 32-bit don't try for more */
                 inbits = NUM_BITS - inbits;
                 ret = Hbitread(bitid1, inbits, &tempbuf);
-                VERIFY(ret, inbits, "Hbitread");
+                VERIFY_VOID(ret, inbits, "Hbitread");
                 inbuf2[i] <<= inbits;
                 inbuf2[i] |= tempbuf;
             }   /* end if */
@@ -226,9 +233,10 @@ test_bitio_read(void)
     RESULT("Hbitendaccess");
 
     test_ptr = (uint8 *) HDmalloc((size_t)((DATASIZE / 4) * DFKNTsize(DFNT_UINT32)));
-    CHECK(test_ptr, NULL, "HDmalloc");
+    CHECK_VOID(test_ptr, NULL, "HDmalloc");
+
     ret = DFKconvert(inbuf2, test_ptr, DFNT_UINT32, (DATASIZE / 4), DFACC_WRITE, 0, 0);
-    CHECK(ret, FAIL, "DFKconvert");
+    RESULT("DFKconvert");
 
     /* check the data */
     if (HDmemcmp(inbuf, test_ptr, DATASIZE) != 0)
@@ -257,19 +265,19 @@ test_bitio_seek(void)
         );
 
     fid = Hopen(TESTFILE_NAME, DFACC_READ | DFACC_WRITE, 0);
-    CHECK(fid, FAIL, "Hopen");
+    CHECK_VOID(fid, FAIL, "Hopen");
 
     MESSAGE(8, printf("Seek & read from start of dataset\n");
         );
     bitid1 = Hstartbitread(fid, BITIO_TAG_1, BITIO_REF_1);
-    CHECK(bitid1, FAIL, "Hstartbitread");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitread");
 
     for (i = 0; i < BUFSIZE; i++)
       {
           ret = Hbitseek(bitid1, (int32)(totbits[i] / 8), (intn) (totbits[i] % 8));
-          CHECK(ret, FAIL, "Hbitseek");
+          CHECK_VOID(ret, FAIL, "Hbitseek");
           ret = Hbitread(bitid1, (intn)outbuf[i], &inbuf2[i]);
-          VERIFY((uint8) ret, outbuf[i], "Hbitread");
+          VERIFY_VOID((uint8) ret, outbuf[i], "Hbitread");
           if (outbuf2[i] != inbuf2[i])
               printf("outbuf[%d]=%u, outbuf2[%d]=%lu inbuf2[%d]=%lu, totbits[%d]=%lu\n", i, outbuf[i], i, (long) outbuf2[i], i, (long) inbuf2[i], i, (long) totbits[i]);
       }     /* end for */
@@ -280,14 +288,14 @@ test_bitio_seek(void)
     MESSAGE(8, printf("Seek & read from end of dataset\n");
         );
     bitid1 = Hstartbitread(fid, BITIO_TAG_1, BITIO_REF_1);
-    CHECK(bitid1, FAIL, "Hstartbitread");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitread");
 
     for (i = BUFSIZE - 1; i >= 0; i--)
       {
           ret = Hbitseek(bitid1, (int32)(totbits[i] / 8), (intn) (totbits[i] % 8));
-          CHECK(ret, FAIL, "Hbitseek");
+          CHECK_VOID(ret, FAIL, "Hbitseek");
           ret = Hbitread(bitid1, (intn)outbuf[i], &inbuf2[i]);
-          VERIFY((uint8) ret, outbuf[i], "Hbitread");
+          VERIFY_VOID((uint8) ret, outbuf[i], "Hbitread");
           if (outbuf2[i] != inbuf2[i])
               printf("outbuf[%d]=%u, outbuf2[%d]=%lu inbuf2[%d]=%lu, totbits[%d]=%lu\n", i, outbuf[i], i, (long) outbuf2[i], i, (long) inbuf2[i], i, (long) totbits[i]);
       }     /* end for */
@@ -298,7 +306,7 @@ test_bitio_seek(void)
     MESSAGE(8, printf("Seek & write from start of dataset\n");
         );
     bitid1 = Hstartbitwrite(fid, BITIO_TAG_1, BITIO_REF_1, 16);
-    CHECK(bitid1, FAIL, "Hstartbitwrite");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitwrite");
 
     MESSAGE(9, printf("Writing new data to every other bit-sequence\n");
         );
@@ -308,9 +316,9 @@ test_bitio_seek(void)
           outbuf2[i] = (uintn)RAND() & maskbuf[outbuf[i]];     /* actual bits to output */
 
           ret = Hbitseek(bitid1, (int32)(totbits[i] / 8), (intn) (totbits[i] % 8));
-          CHECK(ret, FAIL, "Hbitseek");
+          CHECK_VOID(ret, FAIL, "Hbitseek");
           ret = Hbitwrite(bitid1, (intn)outbuf[i], (uint32) outbuf2[i]);
-          VERIFY((uint8) ret, outbuf[i], "Hbitwrite");
+          VERIFY_VOID((uint8) ret, outbuf[i], "Hbitwrite");
       }     /* end for */
 
     ret = Hendbitaccess(bitid1, 0);
@@ -319,14 +327,14 @@ test_bitio_seek(void)
     MESSAGE(9, printf("Verifying new data\n");
         );
     bitid1 = Hstartbitread(fid, BITIO_TAG_1, BITIO_REF_1);
-    CHECK(bitid1, FAIL, "Hstartbitread");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitread");
 
     for (i = 0; i < BUFSIZE; i++)
       {
           ret = Hbitseek(bitid1, (int32)(totbits[i] / 8), (intn) (totbits[i] % 8));
-          CHECK(ret, FAIL, "Hbitseek");
+          RESULT("Hbitseek");
           ret = Hbitread(bitid1, (intn)outbuf[i], &inbuf2[i]);
-          VERIFY((uint8) ret, outbuf[i], "Hbitread");
+          VERIFY_VOID((uint8) ret, outbuf[i], "Hbitread");
           if (outbuf2[i] != inbuf2[i])
               printf("outbuf[%d]=%u, outbuf2[%d]=%lu inbuf2[%d]=%lu, totbits[%d]=%lu\n", i, outbuf[i], i, (long) outbuf2[i], i, (long) inbuf2[i], i, (long) totbits[i]);
       }     /* end for */
@@ -337,7 +345,7 @@ test_bitio_seek(void)
     MESSAGE(8, printf("Seek & write from end of dataset\n");
         );
     bitid1 = Hstartbitwrite(fid, BITIO_TAG_1, BITIO_REF_1, 16);
-    CHECK(bitid1, FAIL, "Hstartbitwrite");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitwrite");
 
     MESSAGE(9, printf("Writing new data to every other bit-sequence from the end\n");
         );
@@ -347,9 +355,9 @@ test_bitio_seek(void)
           outbuf2[i] = (uintn)RAND() & maskbuf[outbuf[i]];     /* actual bits to output */
 
           ret = Hbitseek(bitid1, (int32)(totbits[i] / 8), (intn) (totbits[i] % 8));
-          CHECK(ret, FAIL, "Hbitseek");
+          RESULT("Hbitseek");
           ret = Hbitwrite(bitid1, (intn)outbuf[i], (uint32) outbuf2[i]);
-          VERIFY((uint8) ret, outbuf[i], "Hbitwrite");
+          VERIFY_VOID((uint8) ret, outbuf[i], "Hbitwrite");
       }     /* end for */
 
     ret = Hendbitaccess(bitid1, 0);
@@ -358,14 +366,14 @@ test_bitio_seek(void)
     MESSAGE(9, printf("Verifying new data again\n");
         );
     bitid1 = Hstartbitread(fid, BITIO_TAG_1, BITIO_REF_1);
-    CHECK(bitid1, FAIL, "Hstartbitread");
+    CHECK_VOID(bitid1, FAIL, "Hstartbitread");
 
     for (i = 0; i < BUFSIZE; i++)
       {
           ret = Hbitseek(bitid1, (int32)(totbits[i] / 8), (intn) (totbits[i] % 8));
-          CHECK(ret, FAIL, "Hbitseek");
+          CHECK_VOID(ret, FAIL, "Hbitseek");
           ret = Hbitread(bitid1, (intn)outbuf[i], &inbuf2[i]);
-          VERIFY((uint8) ret, outbuf[i], "Hbitread");
+          VERIFY_VOID((uint8) ret, outbuf[i], "Hbitread");
           if (outbuf2[i] != inbuf2[i])
               printf("outbuf[%d]=%u, outbuf2[%d]=%lu inbuf2[%d]=%lu, totbits[%d]=%lu\n", i, outbuf[i], i, (long) outbuf2[i], i, (long) inbuf2[i], i, (long) totbits[i]);
       }     /* end for */
@@ -373,6 +381,57 @@ test_bitio_seek(void)
     ret = Hendbitaccess(bitid1, 0);
     RESULT("Hbitendaccess");
 
+    MESSAGE(8, printf("Write non-byte filling number of bits and seek to beginning\n");
+        );
+    bitid1 = Hstartbitwrite(fid, BITIO_TAG_3, BITIO_REF_3, 0);
+    CHECK_VOID(bitid1, FAIL, "Hstartbitwrite");
+
+    ret = Hbitappendable(bitid1);
+    RESULT("Hbitappendable");
+
+    MESSAGE(9, printf("Writing 35 bits of data out\n"); );
+
+    ret = Hbitwrite(bitid1, 8, (uint32) outbuf[0]);
+    VERIFY_VOID((uint8) ret, 8, "Hbitwrite");
+    ret = Hbitwrite(bitid1, 8, (uint32) outbuf[1]);
+    VERIFY_VOID((uint8) ret, 8, "Hbitwrite");
+    ret = Hbitwrite(bitid1, 8, (uint32) outbuf[2]);
+    VERIFY_VOID((uint8) ret, 8, "Hbitwrite");
+    ret = Hbitwrite(bitid1, 8, (uint32) outbuf[3]);
+    VERIFY_VOID((uint8) ret, 8, "Hbitwrite");
+    ret = Hbitwrite(bitid1, 3, (uint32) outbuf[4]);
+    VERIFY_VOID((uint8) ret, 3, "Hbitwrite");
+
+    ret = Hbitseek(bitid1, 0, 0);
+    RESULT("Hbitseek");
+
+    ret = Hendbitaccess(bitid1, 0);
+    RESULT("Hbitendaccess");
+
+    /* Read those 35 bits back in */
+    bitid1 = Hstartbitread(fid, BITIO_TAG_3, BITIO_REF_3);
+    CHECK_VOID(bitid1, FAIL, "Hstartbitread");
+
+    ret = Hbitread(bitid1, 8, &inbuf2[0]);
+    VERIFY_VOID((uint8) ret, 8, "Hbitread");
+    ret = Hbitread(bitid1, 8, &inbuf2[1]);
+    VERIFY_VOID((uint8) ret, 8, "Hbitread");
+    ret = Hbitread(bitid1, 8, &inbuf2[2]);
+    VERIFY_VOID((uint8) ret, 8, "Hbitread");
+    ret = Hbitread(bitid1, 8, &inbuf2[3]);
+    VERIFY_VOID((uint8) ret, 8, "Hbitread");
+    ret = Hbitread(bitid1, 3, &inbuf2[4]);
+    VERIFY_VOID((uint8) ret, 3, "Hbitread");
+
+    VERIFY_VOID(outbuf[0],inbuf2[0],"I/O Transfer");
+    VERIFY_VOID(outbuf[1],inbuf2[1],"I/O Transfer");
+    VERIFY_VOID(outbuf[2],inbuf2[2],"I/O Transfer");
+    VERIFY_VOID(outbuf[3],inbuf2[3],"I/O Transfer");
+    VERIFY_VOID((outbuf[4]&maskbuf[3]),inbuf2[4],"I/O Transfer");
+
+    ret = Hendbitaccess(bitid1, 0);
+    RESULT("Hbitendaccess");
+
     ret = Hclose(fid);
     RESULT("Hclose");
 }   /* test_bitio_seek() */
