@@ -1,16 +1,17 @@
-C****************************************************************************
-C* NCSA HDF                                                                 *
-C* Software Development Group                                               *
-C* National Center for Supercomputing Applications                          *
-C* University of Illinois at Urbana-Champaign                               *
-C* 605 E. Springfield, Champaign IL 61820                                   *
-C*                                                                          *
-C* For conditions of distribution and use, see the accompanying             *
-C* hdf/COPYING file.                                                        *
-C*                                                                          *
-C****************************************************************************
+C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+C* Copyright by The HDF Group.                                               *
+C* Copyright by the Board of Trustees of the University of Illinois.         *
+C* All rights reserved.                                                      *
+C*                                                                           *
+C* This file is part of HDF.  The full HDF copyright notice, including       *
+C* terms governing use, modification, and redistribution, is contained in    *
+C* the files COPYING and Copyright.html.  COPYING can be found at the root   *
+C* of the source code distribution tree; Copyright.html can be found at      *
+C* http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+C* access to either file, you may request a copy from help@hdfgroup.org.     *
+C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 C
-C $Id: manf.f,v 1.18 1997/10/24 17:27:56 acheng Exp $
+C $Id: manf.f 4932 2007-09-07 17:17:23Z bmribler $
 C
       subroutine manf (number_failed)
 C
@@ -323,11 +324,15 @@ C**************************************************************
       integer MAXLENLAB, MAXLEN_DESC
       parameter ( MAXLENLAB =    30,
      *            MAXLEN_DESC =  500 )
+      character*15 ERR_FILE
+      parameter (ERR_FILE = 'Fortran_err.dat')
 
       integer  inlablen, indesclen, ret
 
       integer affileinfo, afnumann, afannlist, afannlen
       integer afreadann, afstart, afend, afendaccess, hopen, hclose
+      integer hishdff, hestringf, heprntf
+      character*80 error_message
 
       integer fileh, anh
       integer nflabs, nfdescs, nolabs, nodescs
@@ -338,13 +343,48 @@ C**************************************************************
       character*500 indesc, fanndesc
       integer AN_DATA_LABEL, AN_DATA_DESC, AN_FILE_LABEL, AN_FILE_DESC
       integer DFACC_READ
+      integer error_code
       DFACC_READ = 1
       AN_DATA_LABEL = 0
       AN_DATA_DESC  = 1
       AN_FILE_LABEL = 2
       AN_FILE_DESC  = 3
+      error_code = 0
 
+C ***** Test if the file fname is an HDF file
+C
+C
+      ret = hishdff(fname)
+      if (ret .ne. 1) then
+          num_failed = num_failed + 1
+          write(*,*) 'HISHDFF function failed'
+      endif
+      ret = hestringf(error_code, error_message)
+      if (ret .ne. 0) then
+          num_failed = num_failed + 1
+          write(*,*) 'HESTRINGF function failed'
+          goto 1111
+      endif
+      if (error_message(1:len(error_message)) .ne. "No error") then
+          num_failed = num_failed + 1
+          write(*,*) 'HESTRINGF function failed'
+      endif
+1111  continue
+C
+C     Call hishdff with  file not being an hdf file. Call should return
+C     0 
+C
+      ret = hishdff('manf.f')
+      if (ret .ne. 0) then
+          num_failed = num_failed + 1
+          write(*,*) 'HISHDFF function failed'
+      endif
+C
+C *****  end of hishdff test
+C
 C *****start annotation access on file *****
+      fileh = hopen('nonexist', DFACC_READ,0)
+      ret = heprntf(ERR_FILE, 0)
       fileh = hopen(fname, DFACC_READ,0)
       ret = fileh
       call VRFY(ret, 'hopen', num_failed)
@@ -443,6 +483,8 @@ C ****** close file *******
       call VRFY(ret, 'afend', num_failed)
       ret = hclose(fileh)
       call VRFY(ret, 'hclose', num_failed)
+      ret = hclose(fileh)
+      ret = heprntf(ERR_FILE, 0)
 
 
       return
