@@ -1,16 +1,17 @@
-C****************************************************************************
-C* NCSA HDF                                                                 *
-C* Software Development Group                                               *
-C* National Center for Supercomputing Applications                          *
-C* University of Illinois at Urbana-Champaign                               *
-C* 605 E. Springfield, Champaign IL 61820                                   *
-C*                                                                          *
-C* For conditions of distribution and use, see the accompanying             *
-C* hdf/COPYING file.                                                        *
-C*                                                                          *
-C****************************************************************************
+C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+C* Copyright by The HDF Group.                                               *
+C* Copyright by the Board of Trustees of the University of Illinois.         *
+C* All rights reserved.                                                      *
+C*                                                                           *
+C* This file is part of HDF.  The full HDF copyright notice, including       *
+C* terms governing use, modification, and redistribution, is contained in    *
+C* the files COPYING and Copyright.html.  COPYING can be found at the root   *
+C* of the source code distribution tree; Copyright.html can be found at      *
+C* http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+C* access to either file, you may request a copy from help@hdfgroup.org.     *
+C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 C
-C $Id: tanf.f,v 1.19 1997/10/24 17:28:01 acheng Exp $
+C $Id: tanf.f 5322 2010-01-19 06:26:11Z brtnfld $
 C
       subroutine tanf (number_failed)
 C
@@ -27,6 +28,11 @@ C
 C  Possible bug:  When reading in a label, we have to give it a 
 C                 length that is one greater than MAXLEN_LAB. This
 C                 may be due to a bug in dfan.c in DFANIgetann().
+C
+C                 This was addressed in BUG 1640: Added isfortran 
+C                 flag to DFANIgetann to avoid termination 
+C                 of the string with the null character when the routine 
+C                 is call from FORTRAN, hence no longer need to add one.
 C
 
       implicit none
@@ -196,7 +202,7 @@ C**************************************************************
           number_failed = number_failed + 1
       endif
 
-      ret = daglab(filename, tag, ref, inlabel, MAXLEN_LAB+1)
+      ret = daglab(filename, tag, ref, inlabel, MAXLEN_LAB)
       call VRFY(ret, 'daglab', number_failed)
       if (inlabel .ne. label) then
           print *,'   >>>BAD LABEL.'
