@@ -1,32 +1,24 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.31 $";
+static char RcsId[] = "@(#)$Revision: 6043 $";
 #endif
 
-/* $Id: he_file.c,v 1.31 1998/02/02 21:46:09 smitchel Exp $ */
+/* $Id: he_file.c 6043 2014-01-21 21:09:03Z acheng $ */
 
 /* --- he-file.c  --- file and annotation manipulation routines */
 #include "he.h"
-#ifdef VMS
-#   include <descrip.h>
-#   include <processes.h>
-#   include <unixlib.h>
-/*
-#   include <tpudef.h>
-*/
-#   include <tpu$routines>
-#endif
 
 /* get the prototype for the wait() func. */
 #if defined SUN | defined HP9000 | defined IRIX | defined UNIX386
@@ -88,8 +80,6 @@ int
 annotate(const char *editor, int ann)
 {
 
-#if !defined MAC && !defined WIN386 && !defined(macintosh)
-
     int32       len;            /* length of annotation */
     char       *buf;            /* annotation buffer */
     char       *file;           /* tmp file name */
@@ -124,7 +114,6 @@ annotate(const char *editor, int ann)
           HDfree(buf);
       }
 
-#ifndef VMS
     /* make sure some editor will be used
        * defaults to /usr/bin/ex
        * but should be made a comple time option
@@ -135,17 +124,8 @@ annotate(const char *editor, int ann)
           if (editor == NULL)
               editor = "/usr/bin/ex";
       }
-#ifdef CRAYMPP
-    {	char	cmd[256];
-	if (HDstrlen(editor) > 100) {
-	    fprintf(stderr, "Environment variable EDITOR too big\n");
-	}
-	else {
-	    sprintf(cmd, "%s %s", editor, file);
-	    system(cmd);
-	}
-    }
-#else
+    /* Use the fork/wait or system methods if supported, else no support. */
+#if defined(H4_HAVE_FORK) && defined(H4_HAVE_WAIT)
     if (fork() == 0)
       {
           /* this is the child */
@@ -159,22 +139,16 @@ annotate(const char *editor, int ann)
 
     /* the parent waits for the child to die */
     wait(0);
-#endif
-#else  /* VMS  */
-    if (vfork() == 0)
-        /* this is the child */
-      {
-          intn        ret_status;
- 
-          $DESCRIPTOR(input_file, file);
-          $DESCRIPTOR(output_file, file);
-          ret_status = TPU$EDIT(&input_file, &output_file);
-          fprintf(stderr, "TPU$EDIT return status: %d. \n", ret_status);
-          exit(0);
-      }
-
-    /* the parent waits for the child to die */
-    wait(0);
+#elif defined(H4_HAVE_SYSTEM)
+    {   char    cmd[256];
+        if (HDstrlen(editor) > 100) {
+            fprintf(stderr, "Environment variable EDITOR too big\n");
+        }
+        else {
+            sprintf(cmd, "%s %s", editor, file);
+            system(cmd);
+        }
+    }
 #endif
 
     /* read in edited annotation
@@ -206,16 +180,6 @@ annotate(const char *editor, int ann)
      */
     HDfree(buf);
     return ret;
-
-#else
-    /* shut compiler up */
-    ann = ann;
-    editor = editor;
-
-    return 1;
-
-#endif /* not def MAC & WIN386 & macintosh */
-
 }
 
 extern int  he_backup;
