@@ -1,21 +1,21 @@
-
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#) $Revision: 1.11 $"
+static char RcsId[] = "@(#) $Revision: 6013 $"
 #endif
 
-/* $Id: paltohdf.c,v 1.11 1996/04/09 20:09:44 georgev Exp $ */
+/* $Id: paltohdf.c 6013 2014-01-10 21:19:02Z acheng $ */
 
 /*
    *  paltohdf.c
@@ -31,10 +31,6 @@ static char RcsId[] = "@(#) $Revision: 1.11 $"
    *
    *  This program is in the public domain
  */
-#if defined __MWERKS__
-#include <console.h>
-#endif
-
 #include "hdf.h"
 
 int main(int argc, char *argv[]);
@@ -43,10 +39,6 @@ int         palconv(char *palfile, char *outfile);
 int
 main(int argc, char *argv[])
 {
-#if defined __MWERKS__
-    argc = ccommand(&argv);
-#endif
-
     if (argc != 3)
       {
           printf("Usage:\n");
