@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 1.16 $";
+static char RcsId[] = "@(#)$Revision: 6013 $";
 #endif
 
-/* $Id: r8tohdf.c,v 1.16 1996/11/11 20:40:26 koziol Exp $ */
+/* $Id: r8tohdf.c 6013 2014-01-10 21:19:02Z acheng $ */
 
 /*
    *  r8tohdf.c
@@ -24,10 +25,6 @@ static char RcsId[] = "@(#)$Revision: 1.16 $";
 /* The intrepretation of arguments has changed a little.  A -p introduces a
    palette which will be used for subsequent images, till another -p.
    -i and -c introduce a series of images/compressed images */
-#if defined __MWERKS__
-#include <console.h>
-#endif
-
 #include "hdf.h"
 
 int32       xdim, ydim;
@@ -43,10 +40,6 @@ main(int argc, char *argv[])
     char       *outfile;
     uint16      compress = (uint16) 0;
 
-#if defined __MWERKS__
-    argc = ccommand(&argv);
-#endif
-
     if (argc < 5)
       {
           printf("%s,  version: 1.1   date: July 1, 1992\n", argv[0]);
