@@ -1,20 +1,21 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char *RcsId[] = "@(#)$Revision: 1.33 $";
+static char *RcsId[] = "@(#)$Revision: 6013 $";
 #endif
 
-/* $Id: vmake.c,v 1.33 1998/02/23 16:49:07 acheng Exp $ */
+/* $Id: vmake.c 6013 2014-01-10 21:19:02Z acheng $ */
 
 /*****************************************************************************
 *
@@ -35,10 +36,6 @@ static char *RcsId[] = "@(#)$Revision: 1.33 $";
 *
 ******************************************************************************/
 
-#if defined __MWERKS__
-#include <console.h>
-#endif
-
 #include "hdf.h"
 
 /*
@@ -85,9 +82,6 @@ main(int ac, char **av)
 {
 
     char       *hfile, *vgname, *vsname, *fmt;
-#if defined __MWERKS__
-    ac = ccommand(&av);
-#endif
 
     if (ac < 3)
       {
@@ -126,10 +120,10 @@ main(int ac, char **av)
           int32       vgref, ids[50];
 
           hfile = av[1];
-          sscanf(av[3], "%d", &vgref);
+          sscanf(av[3], "%d", (int *)&vgref);
           for (n = 0, i = 4; i < ac; i++, n++)
             {
-                sscanf(av[i], "%d", &ids[n]);
+                sscanf(av[i], "%d", (int *)&ids[n]);
             }
           vsetlink(hfile, vgref, ids, n);
       }
@@ -403,7 +397,7 @@ inplong(VOIDP x)
 {
     int32       val, ret;
 
-    ret = scanf("%d ", &val);
+    ret = scanf("%d ", (int *)&val);
     *(int32 *)x = (int32) val;
     return (ret);
 }
@@ -609,7 +603,7 @@ separate(char *ss, char *fmt, int32 *num)
           i++;
       }
     if (i > 0)
-        sscanf(ss, "%d", num);
+        sscanf(ss, "%d", (int *)num);
     else
         *num = 1;
     *fmt = ss[i];
