@@ -1,19 +1,20 @@
-/****************************************************************************
- * NCSA HDF                                                                 *
- * Software Development Group                                               *
- * National Center for Supercomputing Applications                          *
- * University of Illinois at Urbana-Champaign                               *
- * 605 E. Springfield, Champaign IL 61820                                   *
- *                                                                          *
- * For conditions of distribution and use, see the accompanying             *
- * hdf/COPYING file.                                                        *
- *                                                                          *
- ****************************************************************************/
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /* Modified from vshow.c by Eric Tsui, 12/25/1994. */
 
 #ifdef RCSID
-static char *RcsId[] = "@(#)$Revision: 1.18 $";
+static char *RcsId[] = "@(#)$Revision: 6043 $";
 #endif
 
 #define VSET_INTERFACE
@@ -25,21 +26,19 @@ static char *RcsId[] = "@(#)$Revision: 1.18 $";
 
 int32
 dumpvd(int32       vd, 
-       file_type_t ft, 
+       file_format_t ff, 
        int         data_only, 
        FILE       *fp, 
        char        separater[2],
        int32       flds_indices[VSFIELDMAX], 
        int         dumpallfields)
 {
-    char        vdname[VSNAMELENMAX];
-    char        fields[VSFIELDMAX*FIELDNAMELENMAX];
-    char        flds[VSFIELDMAX*FIELDNAMELENMAX];
+    char        vdname[VSNAMELENMAX+1];
     int32       j, i, t, interlace, nv, vsize;
     uint8      *bb = NULL;
     uint8      *b = NULL;
     DYN_VWRITELIST *w = NULL;
-    intn       (*vfmtfn[VSFIELDMAX]) (VOIDP ,  file_type_t ft,  FILE *);
+    intn       (*vfmtfn[VSFIELDMAX]) (VOIDP ,  file_format_t ff,  FILE *);
     int32       off[VSFIELDMAX];
     int32       order[VSFIELDMAX];
     int32       nattrs[VSFIELDMAX];
@@ -54,11 +53,12 @@ dumpvd(int32       vd,
     int32       addr_width = 0;
     int32       num_digits;
     int32       address = 0;
-    int32       num_flds;
     int32       nfields;
     int32       cnt1, cnt2;
     int32       cn = 0;
     int32       ret_value = SUCCEED;
+    char        fields[VSFIELDMAX*FIELDNAMELENMAX];
+    char        flds[VSFIELDMAX*FIELDNAMELENMAX];
 
     /* inquire about vdata */
     if (FAIL == VSinquire(vd, &nv, &interlace, fields, &vsize, vdname))
@@ -82,14 +82,9 @@ dumpvd(int32       vd,
       }
 
     done = 0;
-    /* Allocate space for the buffer. */
-    if (( bb = (uint8 *) HDmalloc(bufsize)) == NULL)
-      {
-          fprintf(stderr,"dumpvd: failed to allocate memory \n");
-          ret_value = FAIL;
-          goto done;
-      }
-
+    /* Allocate space for the buffer and terminate hdp if allocation fails. */
+    bb = (uint8 *) HDmalloc(bufsize);
+    CHECK_ALLOC( fields, "fields", "dumpvd" );
     
     if (FAIL == VSsetfields(vd, fields))
       {
@@ -120,31 +115,33 @@ dumpvd(int32       vd,
           /* Display the header of a vdata if the user didn't specify the
              data-only option. */
           if (!data_only)
-            { 
-                if(ft==DASCII)
-                  {
-                      if ((dumpallfields) || (flds_indices[x] == i))
-                        {
-                            fprintf(fp, "- field index %d: [%s], type=%d, order=%d\n",
-                                    (int) i, w->name[i], w->type[i], w->order[i]);
-                            x++;
-                        }
-                  }
-            }	/* if */
-
-          /* display attributes */
-          if (FAIL == dumpattr(vd, i, 1, ft, fp))
-            {
+          { 
+             if(ff==DASCII)
+             {
+                if ((dumpallfields) || (flds_indices[x] == i))
+                {
+                   fprintf(fp, "- field index %d: [%s], type=%d, order=%d\n",
+                          (int) i, w->name[i], w->type[i], w->order[i]);
+                   x++;
+                }
+             }
+             /* display attributes - BMR moved this block inside if(!data_only) 
+		to keep the attributes from being printed - bug #231*/
+             if (FAIL == dumpattr(vd, i, 1, ff, fp))
+             {
                 fprintf(stderr,"dumpvd: dumpattr() failed for vd = %d \n",(int)vd);
                 ret_value = FAIL;
                 goto done;
-            }
+             }
+
+          }	/* if !data_only */
 
           /* Choose a function for displaying a piece of data of a 
              particular type. */
-          switch (w->type[i])
+          switch (w->type[i] & 0xff)
             {
             case DFNT_CHAR:
+	    case DFNT_UCHAR:
                 vfmtfn[i] = fmtchar;
                 break;
 
@@ -191,7 +188,7 @@ dumpvd(int32       vd,
     cn = 0;
     done = count = 0;
     
-    if(ft==DASCII)
+    if(ff==DASCII)
       { 
 
           /* If not just the data will be dumped out, then put an address-type
@@ -235,31 +232,45 @@ dumpvd(int32       vd,
                   }
             }		/* while */
 
-          if (FAIL == (nfields = VSgetfields(vd, flds)))
+          nfields = VSgetfields(vd, flds);
+          if (FAIL == nfields )
             {
                 fprintf(stderr,"dumpvd: VSgetfields failed for vd = %d \n",(int)vd);
                 ret_value = FAIL;
                 goto done;
             }
-          num_flds = vsize / nfields;
 
           cnt1 = 0;
           cnt2 = 0;
           while (done != nv)
-            {
-                /* Determine the amount of data to be read this time. */
-                if ((nv - done) > chunk)
+          {
+              /* Determine the amount of data to be read this time. */
+              if ((nv - done) > chunk)
                     count = chunk;
-                else
+              else
                     count = nv - done;
 
-                /* read and update bookkeeping */
-                if (FAIL == VSread(vd, bb, count, interlace))
-                  {
-                      fprintf(stderr,"dumpvd: VSread failed for vd = %d \n",(int)vd);
-                      ret_value = FAIL;
-                      goto done;
-                  }
+              /* read and update bookkeeping */
+              if (FAIL == VSread(vd, bb, count, interlace))
+              {
+		 /* If the data set has external element, get the external file
+		 name to provide information */
+		 intn extfile_namelen = VSgetexternalfile(vd, 0, NULL, NULL);
+		 if (extfile_namelen > 0)
+		 {
+		    char *extfile_name = NULL;
+		    extfile_name = (char *)HDmalloc(sizeof(char *)*(extfile_namelen+1));
+		    CHECK_ALLOC(extfile_name, "extfile_name", "dumpvd" );
+
+		    /* Get the external file info, we don't need offset here */
+		    extfile_namelen = VSgetexternalfile(vd, extfile_namelen+1, extfile_name, NULL);
+		    ERROR_GOTO_3( "in %s: VSread failed for vd(%d) with external file %s.  Please verify the file exists in the same directory.",
+                        "dumpvd", (int)vd, extfile_name);
+		 }
+		 else
+		    ERROR_GOTO_2( "in %s: VSread failed for vd(%d)",
+                        "dumpvd", (int)vd );
+                }
 
                 done += count;
                 b = bb;
@@ -283,7 +294,7 @@ dumpvd(int32       vd,
                             for (t = 0; t < order[i]; t++)
                               {
                                   if(display)
-                                      cn+=(vfmtfn[i]) (b, ft, fp);
+                                      cn+=(vfmtfn[i]) (b, ff, fp);
                                   b += off[i];
                                   if (display)
                                     {
@@ -363,13 +374,13 @@ dumpvd(int32       vd,
 
     else
       {       /*  binary file  */
-          if (FAIL == (nfields = VSgetfields(vd, flds)))
+          nfields = VSgetfields(vd, flds);
+          if (FAIL == nfields )
             {
                 fprintf(stderr,"dumpvd: VSgetfields failed for vd = %d \n",(int)vd);
                 ret_value = FAIL;
                 goto done;
             }
-          num_flds = vsize / nfields;
 
           cnt1 = 0;
           cnt2 = 0; 
@@ -383,11 +394,25 @@ dumpvd(int32       vd,
 
                 /* read and update bookkeeping */
                 if (FAIL == VSread(vd, bb, count, interlace))
-                  {
-                      fprintf(stderr,"dumpvd: VSread failed for vd = %d \n",(int)vd);
-                      ret_value = FAIL;
-                      goto done;
-                  }
+                {
+		   /* If the data set has external element, get the external
+		      file name to provide information */
+		   intn extfile_namelen = VSgetexternalfile(vd, 0, NULL, NULL);
+		   if (extfile_namelen > 0)
+		   {
+		      char *extfile_name = NULL;
+		      extfile_name = (char *)HDmalloc(sizeof(char *)*(extfile_namelen+1));
+		      CHECK_ALLOC(extfile_name, "extfile_name", "dumpvd" );
+
+		      /* Get the external file info, we don't need offset here */
+		      extfile_namelen = VSgetexternalfile(vd, extfile_namelen+1, extfile_name, NULL);
+		      ERROR_GOTO_3( "in %s: VSread failed for vd(%d) with external file %s.  Please verify the file exists in the same directory",
+                        "dumpvd", (int)vd, extfile_name);
+		   }
+		   else
+		      ERROR_GOTO_2( "in %s: VSread failed for vd(%d)",
+                        "dumpvd", (int)vd );
+                }
 
                 done += count;
                 b = bb;
@@ -411,7 +436,7 @@ dumpvd(int32       vd,
                             for (t = 0; t < order[i]; t++)
                               {
                                   if(display)
-                                      cn+=(vfmtfn[i]) (b, ft, fp);
+                                      cn+=(vfmtfn[i]) (b, ff, fp);
                                   b += off[i];
                                   if (display)
                                     {
@@ -462,7 +487,7 @@ intn
 dumpattr(int32 vid, 
          int32 findex, 
          intn isvs,
-         file_type_t ft, 
+         file_format_t ff, 
          FILE *fp)
 {
     intn          i, k;
@@ -473,19 +498,21 @@ dumpattr(int32 vid,
     int32         i_count;
     int32         i_size, e_size;
     int32         off;
-    uint8         attrbuf[BUFFER];
     uint8         *buf = NULL;
     uint8         *ptr = NULL;
-    intn (*vfmtfn)(VOIDP, file_type_t ft, FILE *);
-    char          name[FIELDNAMELENMAX+1];
+    intn (*vfmtfn)(VOIDP, file_format_t ff, FILE *);
     intn          status;
     intn          ret_value = SUCCEED;
+    char          name[FIELDNAMELENMAX+1];
+    uint8         attrbuf[BUFFER];
 
     /* vdata or vgroup? */
     if (isvs) 
         nattrs = VSfnattrs(vid, findex);
     else
-        nattrs = Vnattrs(vid);
+         /* nattrs = Vnattrs(vid); <- replaced with Vnattrs2 to catch all attributes;
+				      previously, SD attributes were missed by V API */
+        nattrs = Vnattrs2(vid);
 
     if (FAIL == nattrs)
       {
@@ -503,7 +530,8 @@ dumpattr(int32 vid,
           if (isvs)
               status = VSattrinfo(vid, findex, i, name, &i_type, &i_count, &e_size);
           else
-              status = Vattrinfo(vid, i, name, &i_type,&i_count, &e_size);
+	      /* Changed to use updated func of Vattrinfo - BMR, 1/7/2013 */
+              status = Vattrinfo2(vid, i, name, &i_type,&i_count, &e_size, NULL, NULL);
 
           if (status == FAIL) 
             {
@@ -535,7 +563,7 @@ dumpattr(int32 vid,
                   {
                       fprintf(stderr,">>>dumpattr:can't allocate buf for %d'th attribute.\n",i);
                       ret_value = FAIL;
-                      goto done;
+                      goto done;  /* do we want exit here? */
                   }
 
                 alloc_flag = 1;
@@ -544,7 +572,8 @@ dumpattr(int32 vid,
                 if (isvs) 
                     status = VSgetattr(vid, findex, i, (VOIDP)buf);
                 else
-                    status = Vgetattr(vid, i, (VOIDP)buf);
+		    /* Changed to use updated func of Vgetattr - BMR, 1/7/2013 */
+                    status = Vgetattr2(vid, i, (VOIDP)buf);
 
                 if (status == FAIL) 
                   {
@@ -559,7 +588,8 @@ dumpattr(int32 vid,
                 if (isvs) 
                     status = VSgetattr(vid, findex, i, (VOIDP)attrbuf);
                 else
-                    status = Vgetattr(vid, i, (VOIDP)attrbuf);
+		    /* Changed to use updated func of Vgetattr - BMR, 1/7/2013 */
+                    status = Vgetattr2(vid, i, (VOIDP)attrbuf);
 
                 if (status == FAIL) 
                   {
@@ -570,7 +600,7 @@ dumpattr(int32 vid,
             }
 
           /* format output */
-          switch (i_type)  
+          switch (i_type & 0xff)  
             {
             case DFNT_CHAR:
             case DFNT_UCHAR:
@@ -617,7 +647,7 @@ dumpattr(int32 vid,
           cn = 0;
           for (k = 0; k < i_count; k++)  
             {
-                cn += vfmtfn((uint8 *)ptr, ft, fp);
+                cn += vfmtfn((uint8 *)ptr, ff, fp);
                 ptr += off;
                 putchar(' ');
                 cn++;
@@ -649,6 +679,6 @@ done:
               HDfree(buf);
       }
     /* Normal cleanup */
-    
+
     return ret_value;
 }
