@@ -1,8 +1,20 @@
-/*
- *	Copyright 1993, University Corporation for Atmospheric Research
- *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
- */
-/*	$Id: var.c,v 1.22 1997/11/05 19:40:33 koziol Exp $ */
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright 1993, University Corporation for Atmospheric Research           *
+ * See netcdf/COPYRIGHT file for copying and redistribution conditions.      *
+ *                                                                           *
+ * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF.  The full HDF copyright notice, including       *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the files COPYING and Copyright.html.  COPYING can be found at the root   *
+ * of the source code distribution tree; Copyright.html can be found at      *
+ * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+
+/*	$Id: var.c 5981 2013-12-16 16:27:16Z bmribler $ */
 
 #include	<string.h>
 #include	"local_nc.h"
@@ -21,7 +33,7 @@ const int *dims ;
 {
 	NC_var *ret ;
 
-	ret = (NC_var *)HDmalloc(sizeof(NC_var)) ;
+	ret = (NC_var *)HDcalloc(1,sizeof(NC_var)) ;
 	if( ret == NULL )
 		goto alloc_err ;
 
@@ -47,12 +59,15 @@ const int *dims ;
         ret->data_tag = DATA_TAG;  /* Assume normal data unless set   */
         ret->data_offset = 0;      /* Assume data starts at beginning */
         ret->block_size = -1;      /* start off with no block size set */
-        ret->numrecs = 0;
+        ret->numrecs = 0;	   /* Only used in unlimited dimension case */
         ret->aid = FAIL;
         ret->ndg_ref = 0;
+        ret->var_type = UNKNOWN;   /* Unknown whether this var is an SDS or a coord var */
         ret->HDFtype = hdf_map_type(type);
         ret->HDFsize = DFKNTsize(ret->HDFtype);
         ret->is_ragged = FALSE;
+        ret->created = FALSE;      /* This is set in SDcreate() if it's a new SDS */
+        ret->set_length = FALSE;   /* This is set in SDwritedata() if the data needs its length set */
 #endif
 
 	return(ret) ;
@@ -90,6 +105,7 @@ NC_var *var ;
               Free(var->shape) ;
           if(var->dsizes != NULL)
               Free(var->dsizes) ;
+
           if (NC_free_array(var->attrs) == FAIL)
             {
                 ret_value = FAIL;
@@ -133,8 +149,7 @@ NC_array *dims;
 	xszof = NC_xtypelen(var->type) ;
 #endif
 
-	var->shape = NULL ;
-	var->dsizes = NULL ;
+	/* Fixed memory leaks reported in bug# 418. BMR - Apr 8, 01 */
 
 	/*
 	 * Allocate the shape array
@@ -177,6 +192,10 @@ NC_array *dims;
 		}
 		op++ ; ip++ ;
 	}
+
+	/* Free memory if this var already has shape previously allocated */
+	if(var->shape != NULL)
+            Free(var->shape);
 	var->shape = shape ;
 
 	/*
@@ -186,11 +205,15 @@ NC_array *dims;
 	dsizes = (unsigned long *)HDmalloc(ii * sizeof(unsigned long)) ;
 	if(dsizes == NULL)
 	{
-        Free(shape) ;
-        var->shape = NULL;
-		nc_serror("NC_var_dsizes") ;
-		return(-1) ;
+            Free(shape) ;
+            var->shape = NULL;
+	    nc_serror("NC_var_shape") ;
+	    return(-1) ;
 	}
+
+	/* Free memory if this var already has dsizes previously allocated */
+	if(var->dsizes != NULL)
+            Free(var->dsizes);
 	var->dsizes = dsizes ;
 
 	/* 
@@ -224,6 +247,8 @@ out :
 			var->len += 4 - var->len%4 ; /* round up */
 	/*		*dsp += 4 - *dsp%4 ; */
 		}
+    default:
+        break;
 	}
 
 #if 0
@@ -286,7 +311,7 @@ const int dims[] ;
                                       (Void *)var) ;
           if(handle->vars == NULL)
               return(-1) ;
-      } else if(handle->vars->count >= MAX_NC_VARS)
+      } else if(handle->vars->count >= H4_MAX_NC_VARS)
         {
             NCadvise(NC_EMAXVARS, "maximum number of variables %d exceeded",
                      handle->vars->count ) ;
@@ -483,20 +508,20 @@ int *nattrsp ;
 		name[vp->name->len] = 0 ;
 	}
 
-	if(typep != 0)
+	if(typep != NULL)
 		*typep = vp->type ;
-	if(ndimsp != 0)
+	if(ndimsp != NULL)
 	{
 		*ndimsp = vp->assoc->count ;
 	}
-	if(dims != 0)
+	if(dims != NULL)
 	{
 		for(ii = 0 ; ii < vp->assoc->count ; ii++)
 		{
 			dims[ii] = vp->assoc->values[ii] ;
 		}
 	}
-	if(nattrsp != 0)
+	if(nattrsp != NULL)
 	{
 		if( vp->attrs != NULL)
 		{
@@ -700,7 +725,7 @@ int             outcdf;
 	}
 	else
 	{
-		long end[MAX_VAR_DIMS] ;
+		long end[H4_MAX_VAR_DIMS] ;
 		memcpy(end, invp->shape, ndims * sizeof(unsigned long)) ;
 		if(IS_RECVAR(invp))
 		{
@@ -823,7 +848,7 @@ xdr_NC_var(xdrs, vpp)
 
 	if( xdrs->x_op == XDR_DECODE )
 	{
-		*vpp = (NC_var *)HDmalloc(sizeof(NC_var)) ;
+		*vpp = (NC_var *)HDcalloc(1,sizeof(NC_var)) ;
 		if( *vpp == NULL )
 		{
 			nc_serror("xdr_NC_var") ;
