@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Id: generate.c,v 1.9 1998/03/03 22:44:36 acheng Exp $
+ *   $Id: generate.c 6032 2014-01-17 18:13:52Z acheng $
  *********************************************************************/
 
 #include <stdio.h>
@@ -28,8 +28,8 @@ gen_netcdf(filename)
 {
     int idim, ivar, iatt;
     int istat;
-    int dimids[MAX_NC_DIMS];
-    int varids[MAX_NC_VARS];
+    int dimids[H4_MAX_NC_DIMS];
+    int varids[H4_MAX_NC_VARS];
 
     ncid = nccreate (filename, NC_CLOBBER);
 
@@ -95,13 +95,19 @@ gen_c(filename)
     int scalar_atts, vector_atts;
     char *val_string;
     char stmnt[C_MAX_STMNT];
-    char s2[MAX_NC_NAME + 2];
+    char s2[H4_MAX_NC_NAME + 2];
 
     static const char *ctypes[] = {"char","short","nclong","float","double"};
     int ntypes = (sizeof ctypes) / (sizeof ctypes[0]);
 
     /* wrap in main program */
+    cline("#include \"h4config.h\"");
+    cline("#ifdef H4_HAVE_NETCDF");
     cline("#include \"netcdf.h\"");
+    cline("#else");
+    cline("#include \"hdf4_netcdf.h\"");
+    cline("#endif");
+/*    cline("#include \"netcdf.h\""); */
     cline("");
     cline("int");
     sprintf(stmnt, "main() {\t\t\t/* create %s */", filename);
@@ -383,7 +389,7 @@ gen_fortran(filename)
     int vector_atts;
     char *val_string;
     char stmnt[FORT_MAX_STMNT];
-    char s2[MAX_NC_NAME + 2];
+    char s2[H4_MAX_NC_NAME + 2];
     /* Need how many netCDF types there are, because we create an array
      * for each type of attribute. */
     int ntypes = 6;		/* number of netCDF types, NC_BYTE, ... */
@@ -713,37 +719,6 @@ ncftype(type)
      nc_type type;		/* netCDF type code */
 {
     switch (type) {
-#ifdef cray
-#ifndef _CRAYMPP
-      /* Traditional vector pipe cray */
-      case NC_BYTE:
-	return "integer";
-      case NC_CHAR:
-	return "character";
-      case NC_SHORT:
-	return "integer";
-      case NC_LONG:
-	return "integer";
-      case NC_FLOAT:
-	return "real";
-      case NC_DOUBLE:
-	return "real";		/* we don't support CRAY 128-bit doubles */
-#else
-      /* a T3D/E.  INTEGER and REAL are both 8 bytes. */
-      case NC_BYTE:
-	return "integer";
-      case NC_CHAR:
-	return "character";
-      case NC_SHORT:
-	return "integer";
-      case NC_LONG:
-	return "integer*4";
-      case NC_FLOAT:
-	return "real*4";
-      case NC_DOUBLE:
-	return "real";
-#endif	/* (_CRAYMPP) */
-#else
       case NC_BYTE:
 	return "byte";		/* non-standard */
       case NC_CHAR:
@@ -760,7 +735,6 @@ ncftype(type)
 	return "real";
       case NC_DOUBLE:
 	return "double precision";
-#endif	
       default:
 	derror("ncctype: bad type code");
 	return NULL;
@@ -836,7 +810,7 @@ cstring(type,valp, num)
       case NC_LONG:
 	cp = (char *) emalloc (20);
 	longp = (nclong *)valp;
-	(void) sprintf(cp,"%d",* (longp + num));
+	(void) sprintf(cp,"%d",(int)* (longp + num));
 	return cp;
 
       case NC_FLOAT:
@@ -900,7 +874,7 @@ fstring(type,valp, num)
       case NC_LONG:
 	cp = (char *) emalloc (20);
 	longp = (nclong *)valp;
-	(void) sprintf(cp,"%d",* (longp + num));
+	(void) sprintf(cp,"%d",(int)* (longp + num));
 	return cp;
 
       case NC_FLOAT:
